@@ -11,7 +11,7 @@ from astropy.units.quantity import Quantity
 from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
 
-__all__ = ['Constant', 'EMConstant']
+__all__ = ["Constant", "EMConstant"]
 
 
 class ConstantMeta(type):
@@ -44,15 +44,14 @@ class ConstantMeta(type):
                             self._has_incompatible_units.add(name_lower)
                     self._checked_units = True
 
-                if (not self.system and
-                        name_lower in self._has_incompatible_units):
-                    systems = sorted([x for x in instances if x])
+                if not self.system and name_lower in self._has_incompatible_units:
+                    systems = sorted(x for x in instances if x)
                     raise TypeError(
-                        'Constant {!r} does not have physically compatible '
-                        'units across all systems of units and cannot be '
-                        'combined with other values without specifying a '
-                        'system (eg. {}.{})'.format(self.abbrev, self.abbrev,
-                                                      systems[0]))
+                        f"Constant {self.abbrev!r} does not have physically compatible "
+                        "units across all systems of units and cannot be "
+                        "combined with other values without specifying a "
+                        f"system (eg. {self.abbrev}.{systems[0]})"
+                    )
 
                 return meth(self, *args, **kwargs)
 
@@ -60,15 +59,30 @@ class ConstantMeta(type):
 
         # The wrapper applies to so many of the __ methods that it's easier to
         # just exclude the ones it doesn't apply to
-        exclude = set(['__new__', '__array_finalize__', '__array_wrap__',
-                       '__dir__', '__getattr__', '__init__', '__str__',
-                       '__repr__', '__hash__', '__iter__', '__getitem__',
-                       '__len__', '__bool__', '__quantity_subclass__',
-                       '__setstate__'])
+        exclude = {
+            "__new__",
+            "__array_finalize__",
+            "__array_wrap__",
+            "__dir__",
+            "__getattr__",
+            "__init__",
+            "__str__",
+            "__repr__",
+            "__hash__",
+            "__iter__",
+            "__getitem__",
+            "__len__",
+            "__bool__",
+            "__quantity_subclass__",
+            "__setstate__",
+        }
         for attr, value in vars(Quantity).items():
-            if (isinstance(value, types.FunctionType) and
-                    attr.startswith('__') and attr.endswith('__') and
-                    attr not in exclude):
+            if (
+                isinstance(value, types.FunctionType)
+                and attr.startswith("__")
+                and attr.endswith("__")
+                and attr not in exclude
+            ):
                 d[attr] = wrap(value)
 
         return super().__new__(mcls, name, bases, d)
@@ -79,14 +93,38 @@ class Constant(Quantity, metaclass=ConstantMeta):
 
     These objects are quantities that are meant to represent physical
     constants.
+
+    Parameters
+    ----------
+    abbrev : str
+        A typical ASCII text abbreviation of the constant, generally
+        the same as the Python variable used for this constant.
+    name : str
+        Full constant name.
+    value : numbers.Real
+        Constant value. Note that this should be a bare number, not a
+        |Quantity|.
+    unit : str
+        String representation of the constant units.
+    uncertainty : numbers.Real
+        Absolute uncertainty in constant value. Note that this should be
+        a bare number, not a |Quantity|.
+    reference : str, optional
+        Reference where the value is taken from.
+    system : str
+        System of units in which the constant is defined. This can be
+        `None` when the constant's units can be directly converted
+        between systems.
     """
+
     _registry = {}
     _has_incompatible_units = set()
 
-    def __new__(cls, abbrev, name, value, unit, uncertainty,
-                reference=None, system=None):
+    def __new__(
+        cls, abbrev, name, value, unit, uncertainty, reference=None, system=None
+    ):
         if reference is None:
-            reference = getattr(cls, 'default_reference', None)
+            reference = getattr(cls, "default_reference", None)
             if reference is None:
                 raise TypeError(f"{cls} requires a reference.")
         name_lower = name.lower()
@@ -96,9 +134,11 @@ class Constant(Quantity, metaclass=ConstantMeta):
         inst = np.array(value).view(cls)
 
         if system in instances:
-                warnings.warn('Constant {!r} already has a definition in the '
-                              '{!r} system from {!r} reference'.format(
-                              name, system, reference), AstropyUserWarning)
+            warnings.warn(
+                f"Constant {name!r} already has a definition in "
+                f"the {system!r} system from {reference!r} reference",
+                AstropyUserWarning,
+            )
         for c in instances.values():
             if system is not None and not hasattr(c.__class__, system):
                 setattr(c, system, inst)
@@ -119,19 +159,23 @@ class Constant(Quantity, metaclass=ConstantMeta):
         return inst
 
     def __repr__(self):
-        return ('<{} name={!r} value={} uncertainty={} unit={!r} '
-                'reference={!r}>'.format(self.__class__, self.name, self.value,
-                                          self.uncertainty, str(self.unit),
-                                          self.reference))
+        return (
+            f"<{self.__class__} "
+            f"name={self.name!r} "
+            f"value={self.value} "
+            f"uncertainty={self.uncertainty} "
+            f"unit={str(self.unit)!r} "
+            f"reference={self.reference!r}>"
+        )
 
     def __str__(self):
-        return ('  Name   = {}\n'
-                '  Value  = {}\n'
-                '  Uncertainty  = {}\n'
-                '  Unit  = {}\n'
-                '  Reference = {}'.format(self.name, self.value,
-                                           self.uncertainty, self.unit,
-                                           self.reference))
+        return (
+            f"  Name   = {self.name}\n"
+            f"  Value  = {self.value}\n"
+            f"  Uncertainty  = {self.uncertainty}\n"
+            f"  Unit  = {self.unit}\n"
+            f"  Reference = {self.reference}"
+        )
 
     def __quantity_subclass__(self, unit):
         return super().__quantity_subclass__(unit)[0], False
@@ -143,6 +187,7 @@ class Constant(Quantity, metaclass=ConstantMeta):
         ``self``.
         """
         return self
+
     __deepcopy__ = __copy__ = copy
 
     @property
@@ -200,7 +245,7 @@ class Constant(Quantity, metaclass=ConstantMeta):
         the constant, else convert to a Quantity in the appropriate SI units.
         """
 
-        return self._instance_or_super('si')
+        return self._instance_or_super("si")
 
     @property
     def cgs(self):
@@ -208,14 +253,21 @@ class Constant(Quantity, metaclass=ConstantMeta):
         the constant, else convert to a Quantity in the appropriate CGS units.
         """
 
-        return self._instance_or_super('cgs')
+        return self._instance_or_super("cgs")
 
     def __array_finalize__(self, obj):
-        for attr in ('_abbrev', '_name', '_value', '_unit_string',
-                     '_uncertainty', '_reference', '_system'):
+        for attr in (
+            "_abbrev",
+            "_name",
+            "_value",
+            "_unit_string",
+            "_uncertainty",
+            "_reference",
+            "_system",
+        ):
             setattr(self, attr, getattr(obj, attr, None))
 
-        self._checked_units = getattr(obj, '_checked_units', False)
+        self._checked_units = getattr(obj, "_checked_units", False)
 
 
 class EMConstant(Constant):
@@ -227,8 +279,10 @@ class EMConstant(Constant):
         emphasizing that there are multiple EM extensions to CGS.
         """
 
-        raise TypeError("Cannot convert EM constants to cgs because there "
-                        "are different systems for E.M constants within the "
-                        "c.g.s system (ESU, Gaussian, etc.). Instead, "
-                        "directly use the constant with the appropriate "
-                        "suffix (e.g. e.esu, e.gauss, etc.).")
+        raise TypeError(
+            "Cannot convert EM constants to cgs because there "
+            "are different systems for E.M constants within the "
+            "c.g.s system (ESU, Gaussian, etc.). Instead, "
+            "directly use the constant with the appropriate "
+            "suffix (e.g. e.esu, e.gauss, etc.)."
+        )
