@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """
@@ -6,4 +5,4 @@ Read/Write/Interchange methods for `astropy.cosmology`. **NOT public API**.
 """
 
 # Import to register with the I/O machinery
-from . import cosmology, ecsv, mapping, model, row, table, yaml  # noqa: F401, F403
+from . import cosmology, ecsv, html, mapping, model, row, table, yaml  # noqa: F401
