@@ -16,10 +16,10 @@ import numpy as np
 from astropy.units import Quantity
 from astropy.utils import isiterable
 
-__all__ = ['ModelBoundingBox', 'CompoundBoundingBox']
+__all__ = ["ModelBoundingBox", "CompoundBoundingBox"]
 
 
-_BaseInterval = namedtuple('_BaseInterval', "lower upper")
+_BaseInterval = namedtuple("_BaseInterval", "lower upper")
 
 
 class _Interval(_BaseInterval):
@@ -70,8 +70,11 @@ class _Interval(_BaseInterval):
 
         valid_shape = shape in ((2,), (1, 2), (2, 0))
         if not valid_shape:
-            valid_shape = (len(shape) > 0 and shape[0] == 2 and
-                           all(isinstance(b, np.ndarray) for b in interval))
+            valid_shape = (
+                len(shape) > 0
+                and shape[0] == 2
+                and all(isinstance(b, np.ndarray) for b in interval)
+            )
 
         if not isiterable(interval) or not valid_shape:
             raise ValueError(MESSAGE)
@@ -80,8 +83,11 @@ class _Interval(_BaseInterval):
     def _validate_bounds(cls, lower, upper):
         """Validate the bounds are reasonable and construct an interval from them."""
         if (np.asanyarray(lower) > np.asanyarray(upper)).all():
-            warnings.warn(f"Invalid interval: upper bound {upper} "
-                          f"is strictly less than lower bound {lower}.", RuntimeWarning)
+            warnings.warn(
+                f"Invalid interval: upper bound {upper} "
+                f"is strictly less than lower bound {lower}.",
+                RuntimeWarning,
+            )
 
         return cls(lower, upper)
 
@@ -147,7 +153,9 @@ def get_index(model, key) -> int:
         if 0 <= key < len(model.inputs):
             index = key
         else:
-            raise IndexError(f"Integer key: {key} must be non-negative and < {len(model.inputs)}.")
+            raise IndexError(
+                f"Integer key: {key} must be non-negative and < {len(model.inputs)}."
+            )
     else:
         raise ValueError(f"Key value: {key} must be string or integer.")
 
@@ -186,7 +194,7 @@ class _BoundingDomain(abc.ABC):
         on the inputs and returns a complete output.
     """
 
-    def __init__(self, model, ignored: List[int] = None, order: str = 'C'):
+    def __init__(self, model, ignored: List[int] = None, order: str = "C"):
         self._model = model
         self._ignored = self._validate_ignored(ignored)
         self._order = self._get_order(order)
@@ -211,9 +219,11 @@ class _BoundingDomain(abc.ABC):
         if order is None:
             order = self._order
 
-        if order not in ('C', 'F'):
-            raise ValueError("order must be either 'C' (C/python order) or "
-                             f"'F' (Fortran/mathematical order), got: {order}.")
+        if order not in ("C", "F"):
+            raise ValueError(
+                "order must be either 'C' (C/python order) or "
+                f"'F' (Fortran/mathematical order), got: {order}."
+            )
 
         return order
 
@@ -244,7 +254,8 @@ class _BoundingDomain(abc.ABC):
     def __call__(self, *args, **kwargs):
         raise NotImplementedError(
             "This bounding box is fixed by the model and does not have "
-            "adjustable parameters.")
+            "adjustable parameters."
+        )
 
     @abc.abstractmethod
     def fix_inputs(self, model, fixed_inputs: dict):
@@ -322,8 +333,10 @@ class _BoundingDomain(abc.ABC):
         A full set of outputs for case that all inputs are outside domain.
         """
 
-        return [self._base_output(input_shape, fill_value)
-                for _ in range(self._model.n_outputs)], None
+        return [
+            self._base_output(input_shape, fill_value)
+            for _ in range(self._model.n_outputs)
+        ], None
 
     def _modify_output(self, valid_output, valid_index, input_shape, fill_value):
         """
@@ -383,7 +396,9 @@ class _BoundingDomain(abc.ABC):
         """
         outputs = []
         for valid_output in valid_outputs:
-            outputs.append(self._modify_output(valid_output, valid_index, input_shape, fill_value))
+            outputs.append(
+                self._modify_output(valid_output, valid_index, input_shape, fill_value)
+            )
 
         return outputs
 
@@ -409,7 +424,9 @@ class _BoundingDomain(abc.ABC):
         if self._model.n_outputs == 1:
             valid_outputs = [valid_outputs]
 
-        return self._prepare_outputs(valid_outputs, valid_index, input_shape, fill_value)
+        return self._prepare_outputs(
+            valid_outputs, valid_index, input_shape, fill_value
+        )
 
     @staticmethod
     def _get_valid_outputs_unit(valid_outputs, with_units: bool):
@@ -426,10 +443,17 @@ class _BoundingDomain(abc.ABC):
         """
 
         if with_units:
-            return getattr(valid_outputs, 'unit', None)
+            return getattr(valid_outputs, "unit", None)
 
-    def _evaluate_model(self, evaluate: Callable, valid_inputs, valid_index,
-                        input_shape, fill_value, with_units: bool):
+    def _evaluate_model(
+        self,
+        evaluate: Callable,
+        valid_inputs,
+        valid_index,
+        input_shape,
+        fill_value,
+        with_units: bool,
+    ):
         """
         Evaluate the model using the given evaluate routine
 
@@ -460,11 +484,14 @@ class _BoundingDomain(abc.ABC):
         valid_outputs = evaluate(valid_inputs)
         valid_outputs_unit = self._get_valid_outputs_unit(valid_outputs, with_units)
 
-        return self.prepare_outputs(valid_outputs, valid_index,
-                                    input_shape, fill_value), valid_outputs_unit
+        return (
+            self.prepare_outputs(valid_outputs, valid_index, input_shape, fill_value),
+            valid_outputs_unit,
+        )
 
-    def _evaluate(self, evaluate: Callable, inputs, input_shape,
-                  fill_value, with_units: bool):
+    def _evaluate(
+        self, evaluate: Callable, inputs, input_shape, fill_value, with_units: bool
+    ):
         """
         Perform model evaluation steps:
             prepare_inputs -> evaluate -> prepare_outputs
@@ -498,8 +525,9 @@ class _BoundingDomain(abc.ABC):
         if all_out:
             return self._all_out_output(input_shape, fill_value)
         else:
-            return self._evaluate_model(evaluate, valid_inputs, valid_index,
-                                        input_shape, fill_value, with_units)
+            return self._evaluate_model(
+                evaluate, valid_inputs, valid_index, input_shape, fill_value, with_units
+            )
 
     @staticmethod
     def _set_outputs_unit(outputs, valid_outputs_unit):
@@ -520,7 +548,7 @@ class _BoundingDomain(abc.ABC):
         """
 
         if valid_outputs_unit is not None:
-            return Quantity(outputs, valid_outputs_unit, copy=False)
+            return Quantity(outputs, valid_outputs_unit, copy=False, subok=True)
 
         return outputs
 
@@ -547,8 +575,9 @@ class _BoundingDomain(abc.ABC):
         # NOTE: CompoundModel does not currently support units during
         #   evaluation for bounding_box so this feature is turned off
         #   for CompoundModel(s).
-        outputs, valid_outputs_unit = self._evaluate(evaluate, inputs, input_shape,
-                                                     fill_value, self._model.bbox_with_units)
+        outputs, valid_outputs_unit = self._evaluate(
+            evaluate, inputs, input_shape, fill_value, self._model.bbox_with_units
+        )
         return tuple(self._set_outputs_unit(outputs, valid_outputs_unit))
 
 
@@ -576,8 +605,13 @@ class ModelBoundingBox(_BoundingDomain):
         (default), 'F': Fortran/mathematical notation order, e.g. x, y, z.
     """
 
-    def __init__(self, intervals: Dict[int, _Interval], model,
-                 ignored: List[int] = None, order: str = 'C'):
+    def __init__(
+        self,
+        intervals: Dict[int, _Interval],
+        model,
+        ignored: List[int] = None,
+        order: str = "C",
+    ):
         super().__init__(model, ignored, order)
 
         self._intervals = {}
@@ -585,15 +619,16 @@ class ModelBoundingBox(_BoundingDomain):
             self._validate(intervals, order=order)
 
     def copy(self, ignored=None):
-        intervals = {index: interval.copy()
-                     for index, interval in self._intervals.items()}
+        intervals = {
+            index: interval.copy() for index, interval in self._intervals.items()
+        }
 
         if ignored is None:
             ignored = self._ignored.copy()
 
-        return ModelBoundingBox(intervals, self._model,
-                                ignored=ignored,
-                                order=self._order)
+        return ModelBoundingBox(
+            intervals, self._model, ignored=ignored, order=self._order
+        )
 
     @property
     def intervals(self) -> Dict[int, _Interval]:
@@ -606,23 +641,22 @@ class ModelBoundingBox(_BoundingDomain):
         return {self._get_name(index): bbox for index, bbox in self._intervals.items()}
 
     def __repr__(self):
-        parts = [
-            'ModelBoundingBox(',
-            '    intervals={'
-        ]
+        parts = ["ModelBoundingBox(", "    intervals={"]
 
         for name, interval in self.named_intervals.items():
             parts.append(f"        {name}: {interval}")
 
-        parts.append('    }')
+        parts.append("    }")
         if len(self._ignored) > 0:
             parts.append(f"    ignored={self.ignored_inputs}")
 
-        parts.append(f'    model={self._model.__class__.__name__}(inputs={self._model.inputs})')
+        parts.append(
+            f"    model={self._model.__class__.__name__}(inputs={self._model.inputs})"
+        )
         parts.append(f"    order='{self._order}'")
-        parts.append(')')
+        parts.append(")")
 
-        return '\n'.join(parts)
+        return "\n".join(parts)
 
     def __len__(self):
         return len(self._intervals)
@@ -655,10 +689,10 @@ class ModelBoundingBox(_BoundingDomain):
         else:
             order = self._get_order(order)
             inputs = self._model.inputs
-            if order == 'C':
+            if order == "C":
                 inputs = inputs[::-1]
 
-            bbox = tuple([tuple(self[input_name]) for input_name in inputs])
+            bbox = tuple(tuple(self[input_name]) for input_name in inputs)
             if len(bbox) == 1:
                 bbox = bbox[0]
 
@@ -669,7 +703,9 @@ class ModelBoundingBox(_BoundingDomain):
         if isinstance(value, tuple):
             return self.bounding_box() == value
         elif isinstance(value, ModelBoundingBox):
-            return (self.intervals == value.intervals) and (self.ignored == value.ignored)
+            return (self.intervals == value.intervals) and (
+                self.ignored == value.ignored
+            )
         else:
             return False
 
@@ -701,9 +737,11 @@ class ModelBoundingBox(_BoundingDomain):
         return [_input for _input in model_input_index if _input not in self._ignored]
 
     def _validate_sequence(self, bounding_box, order: str = None):
-        """Validate passing tuple of tuples representation (or related) and setting them."""
+        """
+        Validate passing tuple of tuples representation (or related) and setting them.
+        """
         order = self._get_order(order)
-        if order == 'C':
+        if order == "C":
             # If bounding_box is C/python ordered, it needs to be reversed
             # to be in Fortran/mathematical/input order.
             bounding_box = bounding_box[::-1]
@@ -722,8 +760,10 @@ class ModelBoundingBox(_BoundingDomain):
     def _validate_iterable(self, bounding_box, order: str = None):
         """Validate and set any iterable representation"""
         if len(bounding_box) != self._n_inputs:
-            raise ValueError(f"Found {len(bounding_box)} intervals, "
-                             f"but must have exactly {self._n_inputs}.")
+            raise ValueError(
+                f"Found {len(bounding_box)} intervals, "
+                f"but must have exactly {self._n_inputs}."
+            )
 
         if isinstance(bounding_box, dict):
             self._validate_dict(bounding_box)
@@ -738,8 +778,15 @@ class ModelBoundingBox(_BoundingDomain):
             self._validate_iterable(bounding_box, order)
 
     @classmethod
-    def validate(cls, model, bounding_box,
-                 ignored: list = None, order: str = 'C', _preserve_ignore: bool = False, **kwargs):
+    def validate(
+        cls,
+        model,
+        bounding_box,
+        ignored: list = None,
+        order: str = "C",
+        _preserve_ignore: bool = False,
+        **kwargs,
+    ):
         """
         Construct a valid bounding box for a model.
 
@@ -788,8 +835,9 @@ class ModelBoundingBox(_BoundingDomain):
         else:
             ignored = None
 
-        return ModelBoundingBox.validate(model, new.named_intervals,
-                                         ignored=ignored, order=new._order)
+        return ModelBoundingBox.validate(
+            model, new.named_intervals, ignored=ignored, order=new._order
+        )
 
     @property
     def dimension(self):
@@ -798,12 +846,12 @@ class ModelBoundingBox(_BoundingDomain):
     def domain(self, resolution, order: str = None):
         inputs = self._model.inputs
         order = self._get_order(order)
-        if order == 'C':
+        if order == "C":
             inputs = inputs[::-1]
 
         return [self[input_name].domain(resolution) for input_name in inputs]
 
-    def _outside(self,  input_shape, inputs):
+    def _outside(self, input_shape, inputs):
         """
         Get all the input positions which are outside the bounding_box,
         so that the corresponding outputs can be filled with the fill
@@ -892,7 +940,9 @@ class ModelBoundingBox(_BoundingDomain):
         if not all_out:
             for _input in inputs:
                 if input_shape:
-                    valid_input = np.broadcast_to(np.atleast_1d(_input), input_shape)[valid_index]
+                    valid_input = np.broadcast_to(np.atleast_1d(_input), input_shape)[
+                        valid_index
+                    ]
                     if np.isscalar(_input):
                         valid_input = valid_input.item(0)
                     valid_inputs.append(valid_input)
@@ -902,7 +952,7 @@ class ModelBoundingBox(_BoundingDomain):
         return tuple(valid_inputs), valid_index, all_out
 
 
-_BaseSelectorArgument = namedtuple('_BaseSelectorArgument', "index ignore")
+_BaseSelectorArgument = namedtuple("_BaseSelectorArgument", "index ignore")
 
 
 class _SelectorArgument(_BaseSelectorArgument):
@@ -1012,7 +1062,9 @@ class _SelectorArgument(_BaseSelectorArgument):
             if self.name(model) in values:
                 return values[self.name(model)]
             else:
-                raise RuntimeError(f"{self.pretty_repr(model)} was not found in {values}")
+                raise RuntimeError(
+                    f"{self.pretty_repr(model)} was not found in {values}"
+                )
 
     def is_argument(self, model, argument) -> bool:
         """
@@ -1087,14 +1139,12 @@ class _SelectorArguments(tuple):
         model : `~astropy.modeling.Model`
             The Model these selector arguments are for.
         """
-        parts = ['SelectorArguments(']
+        parts = ["SelectorArguments("]
         for argument in self:
-            parts.append(
-                f"    {argument.pretty_repr(model)}"
-            )
-        parts.append(')')
+            parts.append(f"    {argument.pretty_repr(model)}")
+        parts.append(")")
 
-        return '\n'.join(parts)
+        return "\n".join(parts)
 
     @property
     def ignore(self):
@@ -1129,7 +1179,9 @@ class _SelectorArguments(tuple):
         for argument in arguments:
             _input = _SelectorArgument.validate(model, *argument)
             if _input.index in [this.index for this in inputs]:
-                raise ValueError(f"Input: '{get_name(model, _input.index)}' has been repeated.")
+                raise ValueError(
+                    f"Input: '{get_name(model, _input.index)}' has been repeated."
+                )
             inputs.append(_input)
 
         if len(inputs) == 0:
@@ -1152,7 +1204,7 @@ class _SelectorArguments(tuple):
         *inputs :
             All the processed model evaluation inputs.
         """
-        return tuple([argument.get_selector(*inputs) for argument in self])
+        return tuple(argument.get_selector(*inputs) for argument in self)
 
     def is_selector(self, _selector):
         """
@@ -1177,7 +1229,7 @@ class _SelectorArguments(tuple):
         values : dict
             Dictionary of fixed inputs.
         """
-        return tuple([argument.get_fixed_value(model, values) for argument in self])
+        return tuple(argument.get_fixed_value(model, values) for argument in self)
 
     def is_argument(self, model, argument) -> bool:
         """
@@ -1215,7 +1267,9 @@ class _SelectorArguments(tuple):
             if selector_arg.is_argument(model, argument):
                 return index
         else:
-            raise ValueError(f"{argument} does not correspond to any selector argument.")
+            raise ValueError(
+                f"{argument} does not correspond to any selector argument."
+            )
 
     def reduce(self, model, argument):
         """
@@ -1250,7 +1304,9 @@ class _SelectorArguments(tuple):
         """
 
         if self.is_argument(model, argument):
-            raise ValueError(f"{argument}: is a selector argument and cannot be ignored.")
+            raise ValueError(
+                f"{argument}: is a selector argument and cannot be ignored."
+            )
 
         kept_ignore = [get_index(model, argument)]
 
@@ -1265,7 +1321,7 @@ class _SelectorArguments(tuple):
         model : `~astropy.modeling.Model`
             The Model these selector arguments are for.
         """
-        return tuple([selector_arg.named_tuple(model) for selector_arg in self])
+        return tuple(selector_arg.named_tuple(model) for selector_arg in self)
 
 
 class CompoundBoundingBox(_BoundingDomain):
@@ -1295,9 +1351,16 @@ class CompoundBoundingBox(_BoundingDomain):
         The ordering that is assumed for the tuple representation of the
         bounding_boxes.
     """
-    def __init__(self, bounding_boxes: Dict[Any, ModelBoundingBox], model,
-                 selector_args: _SelectorArguments, create_selector: Callable = None,
-                 ignored: List[int] = None, order: str = 'C'):
+
+    def __init__(
+        self,
+        bounding_boxes: Dict[Any, ModelBoundingBox],
+        model,
+        selector_args: _SelectorArguments,
+        create_selector: Callable = None,
+        ignored: List[int] = None,
+        order: str = "C",
+    ):
         super().__init__(model, ignored, order)
 
         self._create_selector = create_selector
@@ -1307,33 +1370,37 @@ class CompoundBoundingBox(_BoundingDomain):
         self._validate(bounding_boxes)
 
     def copy(self):
-        bounding_boxes = {selector: bbox.copy(self.selector_args.ignore)
-                          for selector, bbox in self._bounding_boxes.items()}
+        bounding_boxes = {
+            selector: bbox.copy(self.selector_args.ignore)
+            for selector, bbox in self._bounding_boxes.items()
+        }
 
-        return CompoundBoundingBox(bounding_boxes, self._model,
-                                   selector_args=self._selector_args,
-                                   create_selector=copy.deepcopy(self._create_selector),
-                                   order=self._order)
+        return CompoundBoundingBox(
+            bounding_boxes,
+            self._model,
+            selector_args=self._selector_args,
+            create_selector=copy.deepcopy(self._create_selector),
+            order=self._order,
+        )
 
     def __repr__(self):
-        parts = ['CompoundBoundingBox(',
-                 '    bounding_boxes={']
+        parts = ["CompoundBoundingBox(", "    bounding_boxes={"]
         # bounding_boxes
         for _selector, bbox in self._bounding_boxes.items():
-            bbox_repr = bbox.__repr__().split('\n')
+            bbox_repr = bbox.__repr__().split("\n")
             parts.append(f"        {_selector} = {bbox_repr.pop(0)}")
             for part in bbox_repr:
                 parts.append(f"            {part}")
-        parts.append('    }')
+        parts.append("    }")
 
         # selector_args
-        selector_args_repr = self.selector_args.pretty_repr(self._model).split('\n')
+        selector_args_repr = self.selector_args.pretty_repr(self._model).split("\n")
         parts.append(f"    selector_args = {selector_args_repr.pop(0)}")
         for part in selector_args_repr:
             parts.append(f"        {part}")
-        parts.append(')')
+        parts.append(")")
 
-        return '\n'.join(parts)
+        return "\n".join(parts)
 
     @property
     def bounding_boxes(self) -> Dict[Any, ModelBoundingBox]:
@@ -1347,8 +1414,11 @@ class CompoundBoundingBox(_BoundingDomain):
     def selector_args(self, value):
         self._selector_args = _SelectorArguments.validate(self._model, value)
 
-        warnings.warn("Overriding selector_args may cause problems you should re-validate "
-                      "the compound bounding box before use!", RuntimeWarning)
+        warnings.warn(
+            "Overriding selector_args may cause problems you should re-validate "
+            "the compound bounding box before use!",
+            RuntimeWarning,
+        )
 
     @property
     def named_selector_tuple(self) -> tuple:
@@ -1371,9 +1441,9 @@ class CompoundBoundingBox(_BoundingDomain):
             raise ValueError(f"{_selector} is not a selector!")
 
         ignored = self.selector_args.ignore + self.ignored
-        self._bounding_boxes[_selector] = ModelBoundingBox.validate(self._model, value,
-                                                                    ignored,
-                                                                    order=self._order)
+        self._bounding_boxes[_selector] = ModelBoundingBox.validate(
+            self._model, value, ignored, order=self._order
+        )
 
     def _validate(self, bounding_boxes: dict):
         for _selector, bounding_box in bounding_boxes.items():
@@ -1381,15 +1451,26 @@ class CompoundBoundingBox(_BoundingDomain):
 
     def __eq__(self, value):
         if isinstance(value, CompoundBoundingBox):
-            return (self.bounding_boxes == value.bounding_boxes and
-                    self.selector_args == value.selector_args and
-                    self.create_selector == value.create_selector)
+            return (
+                self.bounding_boxes == value.bounding_boxes
+                and self.selector_args == value.selector_args
+                and self.create_selector == value.create_selector
+            )
         else:
             return False
 
     @classmethod
-    def validate(cls, model, bounding_box: dict, selector_args=None, create_selector=None,
-                 ignored: list = None, order: str = 'C', _preserve_ignore: bool = False, **kwarg):
+    def validate(
+        cls,
+        model,
+        bounding_box: dict,
+        selector_args=None,
+        create_selector=None,
+        ignored: list = None,
+        order: str = "C",
+        _preserve_ignore: bool = False,
+        **kwarg,
+    ):
         """
         Construct a valid compound bounding box for a model.
 
@@ -1418,11 +1499,19 @@ class CompoundBoundingBox(_BoundingDomain):
             bounding_box = bounding_box.bounding_boxes
 
         if selector_args is None:
-            raise ValueError("Selector arguments must be provided "
-                             "(can be passed as part of bounding_box argument)")
+            raise ValueError(
+                "Selector arguments must be provided "
+                "(can be passed as part of bounding_box argument)"
+            )
 
-        return cls(bounding_box, model, selector_args,
-                   create_selector=create_selector, ignored=ignored, order=order)
+        return cls(
+            bounding_box,
+            model,
+            selector_args,
+            create_selector=create_selector,
+            ignored=ignored,
+            order=order,
+        )
 
     def __contains__(self, key):
         return key in self._bounding_boxes
@@ -1479,16 +1568,19 @@ class CompoundBoundingBox(_BoundingDomain):
                 new_selector_key.pop(selector_index)
 
                 if bbox.has_interval(argument):
-                    new_bbox = bbox.fix_inputs(self._model, {argument: value},
-                                               _keep_ignored=True)
+                    new_bbox = bbox.fix_inputs(
+                        self._model, {argument: value}, _keep_ignored=True
+                    )
                 else:
                     new_bbox = bbox.copy()
 
                 matching[tuple(new_selector_key)] = new_bbox
 
         if len(matching) == 0:
-            raise ValueError(f"Attempting to fix input {argument}, but there are no "
-                             f"bounding boxes for argument value {value}.")
+            raise ValueError(
+                f"Attempting to fix input {argument}, but there are no "
+                f"bounding boxes for argument value {value}."
+            )
 
         return matching
 
@@ -1498,17 +1590,24 @@ class CompoundBoundingBox(_BoundingDomain):
         if len(self.selector_args) == 1:
             return matching_bounding_boxes[()]
         else:
-            return CompoundBoundingBox(matching_bounding_boxes, self._model,
-                                       self.selector_args.reduce(self._model, argument))
+            return CompoundBoundingBox(
+                matching_bounding_boxes,
+                self._model,
+                self.selector_args.reduce(self._model, argument),
+            )
 
     def _fix_input_bbox_arg(self, argument, value):
         bounding_boxes = {}
         for selector_key, bbox in self._bounding_boxes.items():
-            bounding_boxes[selector_key] = bbox.fix_inputs(self._model, {argument: value},
-                                                           _keep_ignored=True)
+            bounding_boxes[selector_key] = bbox.fix_inputs(
+                self._model, {argument: value}, _keep_ignored=True
+            )
 
-        return CompoundBoundingBox(bounding_boxes, self._model,
-                                   self.selector_args.add_ignore(self._model, argument))
+        return CompoundBoundingBox(
+            bounding_boxes,
+            self._model,
+            self.selector_args.add_ignore(self._model, argument),
+        )
 
     def fix_inputs(self, model, fixed_inputs: dict):
         """
@@ -1544,5 +1643,6 @@ class CompoundBoundingBox(_BoundingDomain):
             selector_args = None
             bbox_dict = bbox.named_intervals
 
-        return bbox.__class__.validate(model, bbox_dict,
-                                       order=bbox.order, selector_args=selector_args)
+        return bbox.__class__.validate(
+            model, bbox_dict, order=bbox.order, selector_args=selector_args
+        )
