@@ -15,12 +15,12 @@ import operator
 
 import numpy as np
 
-from astropy.units import Quantity
+from astropy.units import MagUnit, Quantity
 from astropy.utils import isiterable
 
 from .utils import array_repr_oneline, get_inputs_and_params
 
-__all__ = ['Parameter', 'InputParameterError', 'ParameterError']
+__all__ = ["Parameter", "InputParameterError", "ParameterError"]
 
 
 class ParameterError(Exception):
@@ -45,7 +45,8 @@ def _tofloat(value):
             # catch arrays with strings or user errors like different
             # types of parameters in a parameter set
             raise InputParameterError(
-                f"Parameter of {type(value)} could not be converted to float")
+                f"Parameter of {type(value)} could not be converted to float"
+            )
     elif isinstance(value, Quantity):
         # Quantities are fine as is
         pass
@@ -56,19 +57,21 @@ def _tofloat(value):
         value = float(value)
     elif isinstance(value, bool):
         raise InputParameterError(
-            "Expected parameter to be of numerical type, not boolean")
+            "Expected parameter to be of numerical type, not boolean"
+        )
     else:
         raise InputParameterError(
-            f"Don't know how to convert parameter of {type(value)} to float")
+            f"Don't know how to convert parameter of {type(value)} to float"
+        )
     return value
 
 
 # Helpers for implementing operator overloading on Parameter
 
+
 def _binary_arithmetic_operation(op, reflected=False):
     @functools.wraps(op)
     def wrapper(self, val):
-
         if self.unit is not None:
             self_value = Quantity(self.value, self.unit)
         else:
@@ -85,7 +88,6 @@ def _binary_arithmetic_operation(op, reflected=False):
 def _binary_comparison_operation(op):
     @functools.wraps(op)
     def wrapper(self, val):
-
         if self.unit is not None:
             self_value = Quantity(self.value, self.unit)
         else:
@@ -99,7 +101,6 @@ def _binary_comparison_operation(op):
 def _unary_arithmetic_operation(op):
     @functools.wraps(op)
     def wrapper(self):
-
         if self.unit is not None:
             self_value = Quantity(self.value, self.unit)
         else:
@@ -178,9 +179,11 @@ class Parameter:
     bounds : tuple
         specify min and max as a single tuple--bounds may not be specified
         simultaneously with min or max
+    mag : bool
+        Specify if the unit of the parameter can be a Magnitude unit or not
     """
 
-    constraints = ('fixed', 'tied', 'bounds')
+    constraints = ("fixed", "tied", "bounds")
     """
     Types of constraints a parameter can have.  Excludes 'min' and 'max'
     which are just aliases for the first and second elements of the 'bounds'
@@ -189,9 +192,23 @@ class Parameter:
     fitters as of this writing.
     """
 
-    def __init__(self, name='', description='', default=None, unit=None,
-                 getter=None, setter=None, fixed=False, tied=False, min=None,
-                 max=None, bounds=None, prior=None, posterior=None):
+    def __init__(
+        self,
+        name="",
+        description="",
+        default=None,
+        unit=None,
+        getter=None,
+        setter=None,
+        fixed=False,
+        tied=False,
+        min=None,
+        max=None,
+        bounds=None,
+        prior=None,
+        posterior=None,
+        mag=False,
+    ):
         super().__init__()
 
         self._model = None
@@ -206,12 +223,15 @@ class Parameter:
             if unit is not None and not unit.is_equivalent(default.unit):
                 raise ParameterDefinitionError(
                     f"parameter default {default} does not have units equivalent to "
-                    f"the required unit {unit}")
+                    f"the required unit {unit}"
+                )
             unit = default.unit
             default = default.value
 
         self._default = default
-        self._unit = unit
+
+        self._mag = mag
+        self._set_unit(unit, force=True)
         # Internal units correspond to raw_units held by the model in the
         # previous implementation. The private _getter and _setter methods
         # use this to convert to and from the public unit defined for the
@@ -230,7 +250,8 @@ class Parameter:
             if min is not None or max is not None:
                 raise ValueError(
                     "bounds may not be specified simultaneously with min or "
-                    f"max when instantiating Parameter {name}")
+                    f"max when instantiating Parameter {name}"
+                )
         else:
             bounds = (min, max)
 
@@ -271,7 +292,8 @@ class Parameter:
             if len(oldvalue[key]) == 0:
                 raise InputParameterError(
                     "Slice assignment outside the parameter dimensions for "
-                    f"'{self.name}'")
+                    f"'{self.name}'"
+                )
             for idx, val in zip(range(*key.indices(len(self))), value):
                 self.__setitem__(idx, val)
         else:
@@ -280,21 +302,22 @@ class Parameter:
             except IndexError:
                 raise InputParameterError(
                     f"Input dimension {key} invalid for {self.name!r} parameter with "
-                    f"dimension {value.shape[0]}")  # likely wrong
+                    f"dimension {value.shape[0]}"
+                )  # likely wrong
 
     def __repr__(self):
         args = f"'{self._name}'"
-        args += f', value={self.value}'
+        args += f", value={self.value}"
 
         if self.unit is not None:
-            args += f', unit={self.unit}'
+            args += f", unit={self.unit}"
 
         for cons in self.constraints:
             val = getattr(self, cons)
             if val not in (None, False, (None, None)):
                 # Maybe non-obvious, but False is the default for the fixed and
                 # tied constraints
-                args += f', {cons}={val}'
+                args += f", {cons}={val}"
 
         return f"{self.__class__.__name__}({args})"
 
@@ -321,9 +344,11 @@ class Parameter:
             # units that the parameter advertises to what it actually
             # uses internally.
             if self.internal_unit:
-                return np.float64(self._getter(self._internal_value,
-                                               self.internal_unit,
-                                               self.unit).value)
+                return np.float64(
+                    self._getter(
+                        self._internal_value, self.internal_unit, self.unit
+                    ).value
+                )
             elif self._getter:
                 return np.float64(self._getter(self._internal_value))
             elif self._setter:
@@ -332,15 +357,16 @@ class Parameter:
     @value.setter
     def value(self, value):
         if isinstance(value, Quantity):
-            raise TypeError("The .value property on parameters should be set"
-                            " to unitless values, not Quantity objects. To set"
-                            "a parameter to a quantity simply set the "
-                            "parameter directly without using .value")
+            raise TypeError(
+                "The .value property on parameters should be set"
+                " to unitless values, not Quantity objects. To set"
+                "a parameter to a quantity simply set the "
+                "parameter directly without using .value"
+            )
         if self._setter is None:
             self._value = np.array(value, dtype=np.float64)
         else:
-            self._internal_value = np.array(self._setter(value),
-                                            dtype=np.float64)
+            self._internal_value = np.array(self._setter(value), dtype=np.float64)
 
     @property
     def unit(self):
@@ -357,14 +383,23 @@ class Parameter:
     @unit.setter
     def unit(self, unit):
         if self.unit is None:
-            raise ValueError('Cannot attach units to parameters that were '
-                             'not initially specified with units')
+            raise ValueError(
+                "Cannot attach units to parameters that were "
+                "not initially specified with units"
+            )
         else:
-            raise ValueError('Cannot change the unit attribute directly, '
-                             'instead change the parameter to a new quantity')
+            raise ValueError(
+                "Cannot change the unit attribute directly, "
+                "instead change the parameter to a new quantity"
+            )
 
     def _set_unit(self, unit, force=False):
         if force:
+            if isinstance(unit, MagUnit) and not self._mag:
+                raise ValueError(
+                    "This parameter does not support the magnitude units such as"
+                    f" {unit}"
+                )
             self._unit = unit
         else:
             self.unit = unit
@@ -396,10 +431,11 @@ class Parameter:
     @quantity.setter
     def quantity(self, quantity):
         if not isinstance(quantity, Quantity):
-            raise TypeError("The .quantity attribute should be set "
-                            "to a Quantity object")
+            raise TypeError(
+                "The .quantity attribute should be set to a Quantity object"
+            )
         self.value = quantity.value
-        self._unit = quantity.unit
+        self._set_unit(quantity.unit, force=True)
 
     @property
     def shape(self):
@@ -430,7 +466,6 @@ class Parameter:
 
     @std.setter
     def std(self, value):
-
         self._std = value
 
     @property
@@ -458,7 +493,7 @@ class Parameter:
 
     @fixed.setter
     def fixed(self, value):
-        """ Fix a parameter. """
+        """Fix a parameter."""
         if not isinstance(value, bool):
             raise ValueError("Value must be boolean")
         self._fixed = value
@@ -553,19 +588,35 @@ class Parameter:
                 self._validator = func
                 return self
             else:
-                raise ValueError("This decorator method expects a callable.\n"
-                                 "The use of this method as a direct validator is\n"
-                                 "deprecated; use the new validate method instead\n")
+                raise ValueError(
+                    "This decorator method expects a callable.\n"
+                    "The use of this method as a direct validator is\n"
+                    "deprecated; use the new validate method instead\n"
+                )
+
         return validator
 
     def validate(self, value):
-        """ Run the validator on this parameter"""
+        """Run the validator on this parameter"""
         if self._validator is not None and self._model is not None:
             self._validator(self._model, value)
 
-    def copy(self, name=None, description=None, default=None, unit=None,
-             getter=None, setter=None, fixed=False, tied=False, min=None,
-             max=None, bounds=None, prior=None, posterior=None):
+    def copy(
+        self,
+        name=None,
+        description=None,
+        default=None,
+        unit=None,
+        getter=None,
+        setter=None,
+        fixed=False,
+        tied=False,
+        min=None,
+        max=None,
+        bounds=None,
+        prior=None,
+        posterior=None,
+    ):
         """
         Make a copy of this `Parameter`, overriding any of its core attributes
         in the process (or an exact copy).
@@ -581,26 +632,26 @@ class Parameter:
         """
 
         kwargs = locals().copy()
-        del kwargs['self']
+        del kwargs["self"]
 
         for key, value in kwargs.items():
             if value is None:
                 # Annoying special cases for min/max where are just aliases for
                 # the components of bounds
-                if key in ('min', 'max'):
+                if key in ("min", "max"):
                     continue
                 else:
                     if hasattr(self, key):
                         value = getattr(self, key)
-                    elif hasattr(self, '_' + key):
-                        value = getattr(self, '_' + key)
+                    elif hasattr(self, "_" + key):
+                        value = getattr(self, "_" + key)
                 kwargs[key] = value
 
         return self.__class__(**kwargs)
 
     @property
     def model(self):
-        """ Return the model this  parameter is associated with."""
+        """Return the model this  parameter is associated with."""
         return self._model
 
     @model.setter
@@ -640,9 +691,11 @@ class Parameter:
 
         if isinstance(wrapper, np.ufunc):
             if wrapper.nin != 1:
-                raise TypeError("A numpy.ufunc used for Parameter "
-                                "getter/setter may only take one input "
-                                "argument")
+                raise TypeError(
+                    "A numpy.ufunc used for Parameter "
+                    "getter/setter may only take one input "
+                    "argument"
+                )
         elif wrapper is None:
             # Just allow non-wrappers to fall through silently, for convenience
             return None
@@ -660,8 +713,10 @@ class Parameter:
                     model_arg = inputs[1].name
                     wrapper = functools.partial(wrapper, **{model_arg: model})
             else:
-                raise TypeError("Parameter getter/setter must be a function "
-                                "of either one or two arguments")
+                raise TypeError(
+                    "Parameter getter/setter must be a function "
+                    "of either one or two arguments"
+                )
 
         return wrapper
 
@@ -670,7 +725,7 @@ class Parameter:
         arr = np.asarray(self.value, dtype=dtype)
 
         if self.unit is not None:
-            arr = Quantity(arr, self.unit, copy=False)
+            arr = Quantity(arr, self.unit, copy=False, subok=True)
 
         return arr
 
@@ -686,8 +741,7 @@ class Parameter:
     __pow__ = _binary_arithmetic_operation(operator.pow)
     __rpow__ = _binary_arithmetic_operation(operator.pow, reflected=True)
     __truediv__ = _binary_arithmetic_operation(operator.truediv)
-    __rtruediv__ = _binary_arithmetic_operation(operator.truediv,
-                                                reflected=True)
+    __rtruediv__ = _binary_arithmetic_operation(operator.truediv, reflected=True)
     __eq__ = _binary_comparison_operation(operator.eq)
     __ne__ = _binary_comparison_operation(operator.ne)
     __lt__ = _binary_comparison_operation(operator.lt)
@@ -706,5 +760,5 @@ def param_repr_oneline(param):
 
     out = array_repr_oneline(param.value)
     if param.unit is not None:
-        out = f'{out} {param.unit!s}'
+        out = f"{out} {param.unit!s}"
     return out
