@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-# -*- coding: utf-8 -*-
 # pylint: disable=invalid-name
 """
 Implements projections--particularly sky projections defined in WCS Paper II
@@ -29,36 +28,36 @@ from .utils import _to_orig_unit, _to_radian
 # List of tuples of the form
 # (long class name without suffix, short WCSLIB projection code):
 _PROJ_NAME_CODE = [
-    ('ZenithalPerspective', 'AZP'),
-    ('SlantZenithalPerspective', 'SZP'),
-    ('Gnomonic', 'TAN'),
-    ('Stereographic', 'STG'),
-    ('SlantOrthographic', 'SIN'),
-    ('ZenithalEquidistant', 'ARC'),
-    ('ZenithalEqualArea', 'ZEA'),
-    ('Airy', 'AIR'),
-    ('CylindricalPerspective', 'CYP'),
-    ('CylindricalEqualArea', 'CEA'),
-    ('PlateCarree', 'CAR'),
-    ('Mercator', 'MER'),
-    ('SansonFlamsteed', 'SFL'),
-    ('Parabolic', 'PAR'),
-    ('Molleweide', 'MOL'),
-    ('HammerAitoff', 'AIT'),
-    ('ConicPerspective', 'COP'),
-    ('ConicEqualArea', 'COE'),
-    ('ConicEquidistant', 'COD'),
-    ('ConicOrthomorphic', 'COO'),
-    ('BonneEqualArea', 'BON'),
-    ('Polyconic', 'PCO'),
-    ('TangentialSphericalCube', 'TSC'),
-    ('COBEQuadSphericalCube', 'CSC'),
-    ('QuadSphericalCube', 'QSC'),
-    ('HEALPix', 'HPX'),
-    ('HEALPixPolar', 'XPH'),
+    ("ZenithalPerspective", "AZP"),
+    ("SlantZenithalPerspective", "SZP"),
+    ("Gnomonic", "TAN"),
+    ("Stereographic", "STG"),
+    ("SlantOrthographic", "SIN"),
+    ("ZenithalEquidistant", "ARC"),
+    ("ZenithalEqualArea", "ZEA"),
+    ("Airy", "AIR"),
+    ("CylindricalPerspective", "CYP"),
+    ("CylindricalEqualArea", "CEA"),
+    ("PlateCarree", "CAR"),
+    ("Mercator", "MER"),
+    ("SansonFlamsteed", "SFL"),
+    ("Parabolic", "PAR"),
+    ("Molleweide", "MOL"),
+    ("HammerAitoff", "AIT"),
+    ("ConicPerspective", "COP"),
+    ("ConicEqualArea", "COE"),
+    ("ConicEquidistant", "COD"),
+    ("ConicOrthomorphic", "COO"),
+    ("BonneEqualArea", "BON"),
+    ("Polyconic", "PCO"),
+    ("TangentialSphericalCube", "TSC"),
+    ("COBEQuadSphericalCube", "CSC"),
+    ("QuadSphericalCube", "QSC"),
+    ("HEALPix", "HPX"),
+    ("HEALPixPolar", "XPH"),
 ]
 
-_NOT_SUPPORTED_PROJ_CODES = ['ZPN']
+_NOT_SUPPORTED_PROJ_CODES = ["ZPN"]
 
 _PROJ_NAME_CODE_MAP = dict(_PROJ_NAME_CODE)
 
@@ -66,10 +65,19 @@ projcodes = [code for _, code in _PROJ_NAME_CODE]
 
 
 __all__ = [
-    'Projection', 'Pix2SkyProjection', 'Sky2PixProjection', 'Zenithal',
-    'Cylindrical', 'PseudoCylindrical', 'Conic', 'PseudoConic', 'QuadCube',
-    'HEALPix', 'AffineTransformation2D', 'projcodes'
-] + list(map('_'.join, product(['Pix2Sky', 'Sky2Pix'], chain(*_PROJ_NAME_CODE))))
+    "Projection",
+    "Pix2SkyProjection",
+    "Sky2PixProjection",
+    "Zenithal",
+    "Cylindrical",
+    "PseudoCylindrical",
+    "Conic",
+    "PseudoConic",
+    "QuadCube",
+    "HEALPix",
+    "AffineTransformation2D",
+    "projcodes",
+] + list(map("_".join, product(["Pix2Sky", "Sky2Pix"], chain(*_PROJ_NAME_CODE))))
 
 
 class _ParameterDS(Parameter):
@@ -83,6 +91,7 @@ class _ParameterDS(Parameter):
     operation) *only as required*.
 
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.dirty = True
@@ -114,7 +123,7 @@ class Projection(Model):
 
     @property
     def prjprm(self):
-        """ WCSLIB ``prjprm`` structure. """
+        """WCSLIB ``prjprm`` structure."""
         self._update_prj()
         return self._prj
 
@@ -160,9 +169,9 @@ class Pix2SkyProjection(Projection):
     _input_units_allow_dimensionless = True
 
     def __new__(cls, *args, **kwargs):
-        long_name = cls.name.split('_')[1]
+        long_name = cls.name.split("_")[1]
         cls.prj_code = _PROJ_NAME_CODE_MAP[long_name]
-        return super(Pix2SkyProjection, cls).__new__(cls)
+        return super().__new__(cls)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -174,18 +183,16 @@ class Pix2SkyProjection(Projection):
             # with no parameters:
             self._prj.set()
 
-        self.inputs = ('x', 'y')
-        self.outputs = ('phi', 'theta')
+        self.inputs = ("x", "y")
+        self.outputs = ("phi", "theta")
 
     @property
     def input_units(self):
-        return {self.inputs[0]: u.deg,
-                self.inputs[1]: u.deg}
+        return {self.inputs[0]: u.deg, self.inputs[1]: u.deg}
 
     @property
     def return_units(self):
-        return {self.outputs[0]: u.deg,
-                self.outputs[1]: u.deg}
+        return {self.outputs[0]: u.deg, self.outputs[1]: u.deg}
 
     def evaluate(self, x, y, *args, **kwargs):
         self._update_prj()
@@ -207,9 +214,9 @@ class Sky2PixProjection(Projection):
     _input_units_allow_dimensionless = True
 
     def __new__(cls, *args, **kwargs):
-        long_name = cls.name.split('_')[1]
+        long_name = cls.name.split("_")[1]
         cls.prj_code = _PROJ_NAME_CODE_MAP[long_name]
-        return super(Sky2PixProjection, cls).__new__(cls)
+        return super().__new__(cls)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -221,18 +228,16 @@ class Sky2PixProjection(Projection):
             # without parameters:
             self._prj.set()
 
-        self.inputs = ('phi', 'theta')
-        self.outputs = ('x', 'y')
+        self.inputs = ("phi", "theta")
+        self.outputs = ("x", "y")
 
     @property
     def input_units(self):
-        return {self.inputs[0]: u.deg,
-                self.inputs[1]: u.deg}
+        return {self.inputs[0]: u.deg, self.inputs[1]: u.deg}
 
     @property
     def return_units(self):
-        return {self.outputs[0]: u.deg,
-                self.outputs[1]: u.deg}
+        return {self.outputs[0]: u.deg, self.outputs[1]: u.deg}
 
     def evaluate(self, phi, theta, *args, **kwargs):
         self._update_prj()
@@ -296,14 +301,19 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
     mu = _ParameterDS(
         default=0.0, description="Distance from point of projection to center of sphere"
     )
-    gamma = _ParameterDS(default=0.0, getter=_to_orig_unit, setter=_to_radian,
-                         description="Look angle γ in degrees (Default = 0°)")
+    gamma = _ParameterDS(
+        default=0.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="Look angle γ in degrees (Default = 0°)",
+    )
 
     @mu.validator
     def mu(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
-                "Zenithal perspective projection is not defined for mu = -1")
+                "Zenithal perspective projection is not defined for mu = -1"
+            )
 
 
 class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
@@ -333,17 +343,21 @@ class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
 
     """
     mu = _ParameterDS(
+        default=0.0, description="Distance from point of projection to center of sphere"
+    )
+    gamma = _ParameterDS(
         default=0.0,
-        description="Distance from point of projection to center of sphere"
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="Look angle γ in degrees (Default=0°)",
     )
-    gamma = _ParameterDS(default=0.0, getter=_to_orig_unit, setter=_to_radian,
-                         description="Look angle γ in degrees (Default=0°)")
 
     @mu.validator
     def mu(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
-                "Zenithal perspective projection is not defined for mu = -1")
+                "Zenithal perspective projection is not defined for mu = -1"
+            )
 
 
 class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
@@ -368,23 +382,27 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
 
     """
     mu = _ParameterDS(
-        default=0.0,
-        description="Distance from point of projection to center of sphere"
+        default=0.0, description="Distance from point of projection to center of sphere"
     )
     phi0 = _ParameterDS(
-        default=0.0, getter=_to_orig_unit, setter=_to_radian,
-        description="The longitude φ₀ of the reference point in degrees (Default=0°)"
+        default=0.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="The longitude φ₀ of the reference point in degrees (Default=0°)",
     )
     theta0 = _ParameterDS(
-        default=90.0, getter=_to_orig_unit, setter=_to_radian,
-        description="The latitude θ₀ of the reference point, in degrees (Default=0°)"
+        default=90.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="The latitude θ₀ of the reference point, in degrees (Default=0°)",
     )
 
     @mu.validator
     def mu(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
-                "Zenithal perspective projection is not defined for mu = -1")
+                "Zenithal perspective projection is not defined for mu = -1"
+            )
 
 
 class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
@@ -412,19 +430,24 @@ class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
         default=0.0, description="Distance from point of projection to center of sphere"
     )
     phi0 = _ParameterDS(
-        default=0.0, getter=_to_orig_unit, setter=_to_radian,
-        description="The longitude φ₀ of the reference point in degrees"
+        default=0.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="The longitude φ₀ of the reference point in degrees",
     )
     theta0 = _ParameterDS(
-        default=0.0, getter=_to_orig_unit, setter=_to_radian,
-        description="The latitude θ₀ of the reference point, in degrees"
+        default=0.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="The latitude θ₀ of the reference point, in degrees",
     )
 
     @mu.validator
     def mu(self, value):
         if np.any(np.equal(value, -1.0)):
             raise InputParameterError(
-                "Zenithal perspective projection is not defined for mu = -1")
+                "Zenithal perspective projection is not defined for mu = -1"
+            )
 
 
 class Pix2Sky_Gnomonic(Pix2SkyProjection, Zenithal):
@@ -633,8 +656,10 @@ class Sky2Pix_Airy(Sky2PixProjection, Zenithal):
         in degrees.  Default is 90°.
 
     """
-    theta_b = _ParameterDS(default=90.0,
-                           description="The latitude at which to minimize the error,in degrees")
+    theta_b = _ParameterDS(
+        default=90.0,
+        description="The latitude at which to minimize the error,in degrees",
+    )
 
 
 class Cylindrical(Projection):
@@ -677,14 +702,12 @@ class Pix2Sky_CylindricalPerspective(Pix2SkyProjection, Cylindrical):
     @mu.validator
     def mu(self, value):
         if np.any(value == -self.lam):
-            raise InputParameterError(
-                "CYP projection is not defined for mu = -lambda")
+            raise InputParameterError("CYP projection is not defined for mu = -lambda")
 
     @lam.validator
     def lam(self, value):
         if np.any(value == -self.mu):
-            raise InputParameterError(
-                "CYP projection is not defined for lambda = -mu")
+            raise InputParameterError("CYP projection is not defined for lambda = -mu")
 
 
 class Sky2Pix_CylindricalPerspective(Sky2PixProjection, Cylindrical):
@@ -707,20 +730,22 @@ class Sky2Pix_CylindricalPerspective(Sky2PixProjection, Cylindrical):
         Radius of the cylinder in spherical radii, λ.  Default is 0.
 
     """
-    mu = _ParameterDS(default=1.0, description="Distance from center of sphere in spherical radii")
-    lam = _ParameterDS(default=1.0, description="Radius of the cylinder in spherical radii")
+    mu = _ParameterDS(
+        default=1.0, description="Distance from center of sphere in spherical radii"
+    )
+    lam = _ParameterDS(
+        default=1.0, description="Radius of the cylinder in spherical radii"
+    )
 
     @mu.validator
     def mu(self, value):
         if np.any(value == -self.lam):
-            raise InputParameterError(
-                "CYP projection is not defined for mu = -lambda")
+            raise InputParameterError("CYP projection is not defined for mu = -lambda")
 
     @lam.validator
     def lam(self, value):
         if np.any(value == -self.mu):
-            raise InputParameterError(
-                "CYP projection is not defined for lambda = -mu")
+            raise InputParameterError("CYP projection is not defined for lambda = -mu")
 
 
 class Pix2Sky_CylindricalEqualArea(Pix2SkyProjection, Cylindrical):
@@ -1298,8 +1323,12 @@ class Sky2Pix_BonneEqualArea(Sky2PixProjection, PseudoConic):
     """
     _separable = True
 
-    theta1 = _ParameterDS(default=0.0, getter=_to_orig_unit, setter=_to_radian,
-                          description="Bonne conformal latitude, in degrees")
+    theta1 = _ParameterDS(
+        default=0.0,
+        getter=_to_orig_unit,
+        setter=_to_radian,
+        description="Bonne conformal latitude, in degrees",
+    )
 
 
 class Pix2Sky_Polyconic(Pix2SkyProjection, PseudoConic):
@@ -1384,8 +1413,7 @@ class Sky2Pix_QuadSphericalCube(Sky2PixProjection, QuadCube):
 
 
 class HEALPix(Projection):
-    r"""Base class for HEALPix projections.
-    """
+    r"""Base class for HEALPix projections."""
 
 
 class Pix2Sky_HEALPix(Pix2SkyProjection, HEALPix):
@@ -1405,8 +1433,12 @@ class Pix2Sky_HEALPix(Pix2SkyProjection, HEALPix):
     """
     _separable = True
 
-    H = _ParameterDS(default=4.0, description="The number of facets in longitude direction.")
-    X = _ParameterDS(default=3.0, description="The number of facets in latitude direction.")
+    H = _ParameterDS(
+        default=4.0, description="The number of facets in longitude direction."
+    )
+    X = _ParameterDS(
+        default=3.0, description="The number of facets in latitude direction."
+    )
 
 
 class Sky2Pix_HEALPix(Sky2PixProjection, HEALPix):
@@ -1426,8 +1458,12 @@ class Sky2Pix_HEALPix(Sky2PixProjection, HEALPix):
     """
     _separable = True
 
-    H = _ParameterDS(default=4.0, description="The number of facets in longitude direction.")
-    X = _ParameterDS(default=3.0, description="The number of facets in latitude direction.")
+    H = _ParameterDS(
+        default=4.0, description="The number of facets in longitude direction."
+    )
+    X = _ParameterDS(
+        default=3.0, description="The number of facets in latitude direction."
+    )
 
 
 class Pix2Sky_HEALPixPolar(Pix2SkyProjection, HEALPix):
@@ -1461,6 +1497,7 @@ class AffineTransformation2D(Model):
         translation to apply to the inputs
 
     """
+
     n_inputs = 2
     n_outputs = 2
 
@@ -1477,7 +1514,8 @@ class AffineTransformation2D(Model):
 
         if np.shape(value) != (2, 2):
             raise InputParameterError(
-                "Expected transformation matrix to be a 2x2 array")
+                "Expected transformation matrix to be a 2x2 array"
+            )
 
     @translation.validator
     def translation(self, value):
@@ -1487,11 +1525,14 @@ class AffineTransformation2D(Model):
         resultant Numpy array has ``ndim=2`` but the shape is ``(1, 2)``.
         """
 
-        if not ((np.ndim(value) == 1 and np.shape(value) == (2,)) or
-                (np.ndim(value) == 2 and np.shape(value) == (1, 2))):
+        if not (
+            (np.ndim(value) == 1 and np.shape(value) == (2,))
+            or (np.ndim(value) == 2 and np.shape(value) == (1, 2))
+        ):
             raise InputParameterError(
                 "Expected translation vector to be a 2 element row or column "
-                "vector array")
+                "vector array"
+            )
 
     def __init__(self, matrix=matrix, translation=translation, **kwargs):
         super().__init__(matrix=matrix, translation=translation, **kwargs)
@@ -1510,8 +1551,9 @@ class AffineTransformation2D(Model):
 
         if det == 0:
             raise InputParameterError(
-                f"Transformation matrix is singular; {self.__class__.__name__} model does not "
-                "have an inverse")
+                f"Transformation matrix is singular; {self.__class__.__name__} model"
+                " does not have an inverse"
+            )
 
         matrix = np.linalg.inv(self.matrix.value)
         if self.matrix.unit is not None:
@@ -1537,9 +1579,9 @@ class AffineTransformation2D(Model):
 
         shape = x.shape or (1,)
         # Use asarray to ensure loose the units.
-        inarr = np.vstack([np.asarray(x).ravel(),
-                           np.asarray(y).ravel(),
-                           np.ones(x.size, x.dtype)])
+        inarr = np.vstack(
+            [np.asarray(x).ravel(), np.asarray(y).ravel(), np.ones(x.size, x.dtype)]
+        )
 
         if inarr.shape[0] != 3 or inarr.ndim != 2:
             raise ValueError("Incompatible input shapes")
@@ -1554,10 +1596,12 @@ class AffineTransformation2D(Model):
     @staticmethod
     def _create_augmented_matrix(matrix, translation):
         unit = None
-        if any([hasattr(translation, 'unit'), hasattr(matrix, 'unit')]):
-            if not all([hasattr(translation, 'unit'), hasattr(matrix, 'unit')]):
-                raise ValueError("To use AffineTransformation with quantities, "
-                                 "both matrix and unit need to be quantities.")
+        if any([hasattr(translation, "unit"), hasattr(matrix, "unit")]):
+            if not all([hasattr(translation, "unit"), hasattr(matrix, "unit")]):
+                raise ValueError(
+                    "To use AffineTransformation with quantities, "
+                    "both matrix and unit need to be quantities."
+                )
             unit = translation.unit
             # matrix should have the same units as translation
             if not (matrix.unit / translation.unit) == u.dimensionless_unscaled:
@@ -1583,8 +1627,8 @@ class AffineTransformation2D(Model):
 
 for long_name, short_name in _PROJ_NAME_CODE:
     # define short-name projection equivalent classes:
-    globals()['Pix2Sky_' + short_name] = globals()['Pix2Sky_' + long_name]
-    globals()['Sky2Pix_' + short_name] = globals()['Sky2Pix_' + long_name]
+    globals()["Pix2Sky_" + short_name] = globals()["Pix2Sky_" + long_name]
+    globals()["Sky2Pix_" + short_name] = globals()["Sky2Pix_" + long_name]
     # set inverse classes:
-    globals()['Pix2Sky_' + long_name]._inv_cls = globals()['Sky2Pix_' + long_name]
-    globals()['Sky2Pix_' + long_name]._inv_cls = globals()['Pix2Sky_' + long_name]
+    globals()["Pix2Sky_" + long_name]._inv_cls = globals()["Sky2Pix_" + long_name]
+    globals()["Sky2Pix_" + long_name]._inv_cls = globals()["Pix2Sky_" + long_name]
