@@ -1,23 +1,22 @@
-"""Implements the Astropy TestRunner which is a thin wrapper around py.test."""
+"""Implements the Astropy TestRunner which is a thin wrapper around pytest."""
 
+import copy
+import glob
 import inspect
 import os
-import glob
-import copy
 import shlex
 import sys
 import tempfile
 import warnings
-import importlib
 from collections import OrderedDict
-from importlib.util import find_spec
 from functools import wraps
+from importlib.util import find_spec
 
-from astropy.config.paths import set_temp_config, set_temp_cache
+from astropy.config.paths import set_temp_cache, set_temp_config
 from astropy.utils import find_current_module
-from astropy.utils.exceptions import AstropyWarning, AstropyDeprecationWarning
+from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyWarning
 
-__all__ = ['TestRunner', 'TestRunnerBase', 'keyword']
+__all__ = ["TestRunner", "TestRunnerBase", "keyword"]
 
 
 class keyword:
@@ -56,12 +55,12 @@ class TestRunnerBase:
 
     A test runner can be constructed by creating a subclass of this class and
     defining 'keyword' methods. These are methods that have the
-    `~astropy.tests.runner.keyword` decorator, these methods are used to
+    :class:`~astropy.tests.runner.keyword` decorator, these methods are used to
     construct allowed keyword arguments to the
-    `~astropy.tests.runner.TestRunnerBase.run_tests` method as a way to allow
+    ``run_tests`` method as a way to allow
     customization of individual keyword arguments (and associated logic)
     without having to re-implement the whole
-    `~astropy.tests.runner.TestRunnerBase.run_tests` method.
+    ``run_tests`` method.
 
     Examples
     --------
@@ -101,7 +100,7 @@ class TestRunnerBase:
         functions = inspect.getmembers(cls, predicate=inspect.isfunction)
 
         # Filter out anything that's not got the name 'keyword'
-        keywords = filter(lambda func: func[1].__name__ == 'keyword', functions)
+        keywords = filter(lambda func: func[1].__name__ == "keyword", functions)
         # Sort all keywords based on the priority flag.
         sorted_keywords = sorted(keywords, key=lambda x: x[1]._priority, reverse=True)
 
@@ -126,9 +125,9 @@ class TestRunnerBase:
             # Construct the default kwargs dict and docstring
             cls.keywords[name] = func._default_value
             if func.__doc__:
-                doc_keywords += ' '*8
+                doc_keywords += " " * 8
                 doc_keywords += func.__doc__.strip()
-                doc_keywords += '\n\n'
+                doc_keywords += "\n\n"
 
         cls.run_tests.__doc__ = cls.RUN_TESTS_DOCSTRING.format(keywords=doc_keywords)
 
@@ -147,7 +146,9 @@ class TestRunnerBase:
 
             # Allow disabling of options in a subclass
             if result is NotImplemented:
-                raise TypeError(f"run_tests() got an unexpected keyword argument {keyword}")
+                raise TypeError(
+                    f"run_tests() got an unexpected keyword argument {keyword}"
+                )
 
             # keyword methods must return a list
             if not isinstance(result, list):
@@ -157,8 +158,7 @@ class TestRunnerBase:
 
         return args
 
-    RUN_TESTS_DOCSTRING = \
-        """
+    RUN_TESTS_DOCSTRING = """
         Run the tests for the package.
 
         This method builds arguments for and then calls ``pytest.main``.
@@ -169,12 +169,18 @@ class TestRunnerBase:
 
         """
 
-    _required_dependencies = ['pytest', 'pytest_remotedata', 'pytest_doctestplus', 'pytest_astropy_header']
+    _required_dependencies = [
+        "pytest",
+        "pytest_remotedata",
+        "pytest_doctestplus",
+        "pytest_astropy_header",
+    ]
     _missing_dependancy_error = (
         "Test dependencies are missing: {module}. You should install the "
         "'pytest-astropy' package (you may need to update the package if you "
         "have a previous version installed, e.g., "
-        "'pip install pytest-astropy --upgrade' or the equivalent with conda).")
+        "'pip install pytest-astropy --upgrade' or the equivalent with conda)."
+    )
 
     @classmethod
     def _has_test_dependencies(cls):  # pragma: no cover
@@ -184,27 +190,19 @@ class TestRunnerBase:
             spec = find_spec(module)
             # Checking loader accounts for packages that were uninstalled
             if spec is None or spec.loader is None:
-                raise RuntimeError(
-                    cls._missing_dependancy_error.format(module=module))
+                raise RuntimeError(cls._missing_dependancy_error.format(module=module))
 
     def run_tests(self, **kwargs):
-
         # The following option will include eggs inside a .eggs folder in
         # sys.path when running the tests. This is possible so that when
-        # runnning python setup.py test, test dependencies installed via e.g.
+        # running pytest, test dependencies installed via e.g.
         # tests_requires are available here. This is not an advertised option
         # since it is only for internal use
-        if kwargs.pop('add_local_eggs_to_path', False):
-
+        if kwargs.pop("add_local_eggs_to_path", False):
             # Add each egg to sys.path individually
-            for egg in glob.glob(os.path.join('.eggs', '*.egg')):
+            for egg in glob.glob(os.path.join(".eggs", "*.egg")):
                 sys.path.insert(0, egg)
 
-            # We now need to force reload pkg_resources in case any pytest
-            # plugins were added above, so that their entry points are picked up
-            import pkg_resources
-            importlib.reload(pkg_resources)
-
         self._has_test_dependencies()  # pragma: no cover
 
         # The docstring for this method is defined as a class variable.
@@ -218,14 +216,16 @@ class TestRunnerBase:
         passed_kwargs = set(kwargs.keys())
         if not passed_kwargs.issubset(allowed_kwargs):
             wrong_kwargs = list(passed_kwargs.difference(allowed_kwargs))
-            raise TypeError("run_tests() got an unexpected keyword argument {}".format(wrong_kwargs[0]))
+            raise TypeError(
+                f"run_tests() got an unexpected keyword argument {wrong_kwargs[0]}"
+            )
 
         args = self._generate_args(**kwargs)
 
-        if kwargs.get('plugins', None) is not None:
-            plugins = kwargs.pop('plugins')
-        elif self.keywords.get('plugins', None) is not None:
-            plugins = self.keywords['plugins']
+        if kwargs.get("plugins", None) is not None:
+            plugins = kwargs.pop("plugins")
+        elif self.keywords.get("plugins", None) is not None:
+            plugins = self.keywords["plugins"]
         else:
             plugins = []
 
@@ -236,12 +236,12 @@ class TestRunnerBase:
         # to do it here - but at the same time the code here doesn't work when
         # running tests in parallel mode because this uses subprocesses which
         # don't know about the temporary config/cache.
-        astropy_config = tempfile.mkdtemp('astropy_config')
-        astropy_cache = tempfile.mkdtemp('astropy_cache')
+        astropy_config = tempfile.mkdtemp("astropy_config")
+        astropy_cache = tempfile.mkdtemp("astropy_cache")
 
         # Have to use nested with statements for cross-Python support
         # Note, using these context managers here is superfluous if the
-        # config_dir or cache_dir options to py.test are in use, but it's
+        # config_dir or cache_dir options to pytest are in use, but it's
         # also harmless to nest the contexts
         with set_temp_config(astropy_config, delete=True):
             with set_temp_cache(astropy_cache, delete=True):
@@ -252,7 +252,7 @@ class TestRunnerBase:
         """
         Constructs a `TestRunner` to run in the given path, and returns a
         ``test()`` function which takes the same arguments as
-        `TestRunner.run_tests`.
+        ``TestRunner.run_tests``.
 
         The returned ``test()`` function will be defined in the module this
         was called from.  This is used to implement the ``astropy.test()``
@@ -261,7 +261,7 @@ class TestRunnerBase:
 
         runner = cls(path)
 
-        @wraps(runner.run_tests, ('__doc__',))
+        @wraps(runner.run_tests, ("__doc__",))
         def test(**kwargs):
             return runner.run_tests(**kwargs)
 
@@ -275,7 +275,7 @@ class TestRunnerBase:
         # used to determine the signature to display in help() which is
         # not useful in this case.  We don't really care in this case if the
         # function was wrapped either
-        if hasattr(test, '__wrapped__'):
+        if hasattr(test, "__wrapped__"):
             del test.__wrapped__
 
         test.__test__ = False
@@ -309,16 +309,15 @@ class TestRunner(TestRunnerBase):
         Returns
         -------
         paths : list of str
-            List of stings of existing package paths.
+            List of strings of existing package paths.
         """
         packages = packages.split(",")
 
         paths = []
         for package in packages:
-            path = os.path.join(
-                base_path, package.replace('.', os.path.sep))
+            path = os.path.join(base_path, package.replace(".", os.path.sep))
             if not os.path.isdir(path):
-                info = {'name': package, 'path': path}
+                info = {"name": package, "path": path}
                 if error is not None:
                     raise ValueError(error.format(**info))
                 if warning is not None:
@@ -336,7 +335,8 @@ class TestRunner(TestRunnerBase):
                 "The coverage option is ignored on run_tests, since it "
                 "can not be made to work in that context.  Use "
                 "'python setup.py test --coverage' instead.",
-                AstropyWarning)
+                AstropyWarning,
+            )
 
         return []
 
@@ -353,12 +353,12 @@ class TestRunner(TestRunnerBase):
         if package is None:
             self.package_path = [self.base_path]
         else:
-            error_message = ('package to test is not found: {name} '
-                             '(at path {path}).')
-            self.package_path = self.packages_path(package, self.base_path,
-                                                   error=error_message)
+            error_message = "package to test is not found: {name} (at path {path})."
+            self.package_path = self.packages_path(
+                package, self.base_path, error=error_message
+            )
 
-        if not kwargs['test_path']:
+        if not kwargs["test_path"]:
             return self.package_path
 
         return []
@@ -373,34 +373,38 @@ class TestRunner(TestRunnerBase):
         """
         all_args = []
         # Ensure that the package kwarg has been run.
-        self.package(kwargs['package'], kwargs)
+        self.package(kwargs["package"], kwargs)
         if test_path:
             base, ext = os.path.splitext(test_path)
 
-            if ext in ('.rst', ''):
-                if kwargs['docs_path'] is None:
+            if ext in (".rst", ""):
+                if kwargs["docs_path"] is None:
                     # This shouldn't happen from "python setup.py test"
                     raise ValueError(
-                        "Can not test .rst files without a docs_path "
-                        "specified.")
+                        "Can not test .rst files without a docs_path specified."
+                    )
 
-                abs_docs_path = os.path.abspath(kwargs['docs_path'])
+                abs_docs_path = os.path.abspath(kwargs["docs_path"])
                 abs_test_path = os.path.abspath(
-                    os.path.join(abs_docs_path, os.pardir, test_path))
+                    os.path.join(abs_docs_path, os.pardir, test_path)
+                )
 
                 common = os.path.commonprefix((abs_docs_path, abs_test_path))
 
                 if os.path.exists(abs_test_path) and common == abs_docs_path:
                     # Turn on the doctest_rst plugin
-                    all_args.append('--doctest-rst')
+                    all_args.append("--doctest-rst")
                     test_path = abs_test_path
 
             # Check that the extensions are in the path and not at the end to
             # support specifying the name of the test, i.e.
             # test_quantity.py::test_unit
-            if not (os.path.isdir(test_path) or ('.py' in test_path or '.rst' in test_path)):
-                raise ValueError("Test path must be a directory or a path to "
-                                 "a .py or .rst file")
+            if not (
+                os.path.isdir(test_path) or (".py" in test_path or ".rst" in test_path)
+            ):
+                raise ValueError(
+                    "Test path must be a directory or a path to a .py or .rst file"
+                )
 
             return all_args + [test_path]
 
@@ -414,7 +418,7 @@ class TestRunner(TestRunnerBase):
             keyword argument.
         """
         if args:
-            return shlex.split(args, posix=not sys.platform.startswith('win'))
+            return shlex.split(args, posix=not sys.platform.startswith("win"))
 
         return []
 
@@ -433,11 +437,11 @@ class TestRunner(TestRunnerBase):
     def verbose(self, verbose, kwargs):
         """
         verbose : bool, optional
-            Convenience option to turn on verbose output from py.test. Passing
+            Convenience option to turn on verbose output from pytest. Passing
             True is the same as specifying ``-v`` in ``args``.
         """
         if verbose:
-            return ['-v']
+            return ["-v"]
 
         return []
 
@@ -445,19 +449,19 @@ class TestRunner(TestRunnerBase):
     def pastebin(self, pastebin, kwargs):
         """
         pastebin : ('failed', 'all', None), optional
-            Convenience option for turning on py.test pastebin output. Set to
+            Convenience option for turning on pytest pastebin output. Set to
             'failed' to upload info for failed tests, or 'all' to upload info
             for all tests.
         """
         if pastebin is not None:
-            if pastebin in ['failed', 'all']:
-                return [f'--pastebin={pastebin}']
+            if pastebin in ["failed", "all"]:
+                return [f"--pastebin={pastebin}"]
             else:
                 raise ValueError("pastebin should be 'failed' or 'all'")
 
         return []
 
-    @keyword(default_value='none')
+    @keyword(default_value="none")
     def remote_data(self, remote_data, kwargs):
         """
         remote_data : {'none', 'astropy', 'any'}, optional
@@ -468,19 +472,21 @@ class TestRunner(TestRunnerBase):
         """
 
         if remote_data is True:
-            remote_data = 'any'
+            remote_data = "any"
         elif remote_data is False:
-            remote_data = 'none'
-        elif remote_data not in ('none', 'astropy', 'any'):
-            warnings.warn("The remote_data option should be one of "
-                          "none/astropy/any (found {}). For backward-compatibility, "
-                          "assuming 'any', but you should change the option to be "
-                          "one of the supported ones to avoid issues in "
-                          "future.".format(remote_data),
-                          AstropyDeprecationWarning)
-            remote_data = 'any'
+            remote_data = "none"
+        elif remote_data not in ("none", "astropy", "any"):
+            warnings.warn(
+                "The remote_data option should be one of "
+                f"none/astropy/any (found {remote_data}). For backward-compatibility, "
+                "assuming 'any', but you should change the option to be "
+                "one of the supported ones to avoid issues in "
+                "future.",
+                AstropyDeprecationWarning,
+            )
+            remote_data = "any"
 
-        return [f'--remote-data={remote_data}']
+        return [f"--remote-data={remote_data}"]
 
     @keyword()
     def pep8(self, pep8, kwargs):
@@ -491,12 +497,14 @@ class TestRunner(TestRunnerBase):
         """
         if pep8:
             try:
-                import pytest_pep8  # pylint: disable=W0611
+                import pytest_pep8  # noqa: F401
             except ImportError:
-                raise ImportError('PEP8 checking requires pytest-pep8 plugin: '
-                                  'https://pypi.org/project/pytest-pep8')
+                raise ImportError(
+                    "PEP8 checking requires pytest-pep8 plugin: "
+                    "https://pypi.org/project/pytest-pep8"
+                )
             else:
-                return ['--pep8', '-k', 'pep8']
+                return ["--pep8", "-k", "pep8"]
 
         return []
 
@@ -508,7 +516,7 @@ class TestRunner(TestRunnerBase):
             specifying ``--pdb`` in ``args``.
         """
         if pdb:
-            return ['--pdb']
+            return ["--pdb"]
         return []
 
     @keyword()
@@ -520,19 +528,21 @@ class TestRunner(TestRunnerBase):
             ``psutil`` package.
         """
         if open_files:
-            if kwargs['parallel'] != 0:
+            if kwargs["parallel"] != 0:
                 raise SystemError(
                     "open file detection may not be used in conjunction with "
-                    "parallel testing.")
+                    "parallel testing."
+                )
 
             try:
-                import psutil  # pylint: disable=W0611
+                import psutil  # noqa: F401
             except ImportError:
                 raise SystemError(
                     "open file detection requested, but psutil package "
-                    "is not installed.")
+                    "is not installed."
+                )
 
-            return ['--open-files']
+            return ["--open-files"]
 
             print("Checking for unclosed files")
 
@@ -548,12 +558,13 @@ class TestRunner(TestRunnerBase):
         """
         if parallel != 0:
             try:
-                from xdist import plugin # noqa
+                from xdist import plugin  # noqa: F401
             except ImportError:
                 raise SystemError(
-                    "running tests in parallel requires the pytest-xdist package")
+                    "running tests in parallel requires the pytest-xdist package"
+                )
 
-            return ['-n', str(parallel)]
+            return ["-n", str(parallel)]
 
         return []
 
@@ -565,17 +576,20 @@ class TestRunner(TestRunnerBase):
         """
 
         paths = []
-        if docs_path is not None and not kwargs['skip_docs']:
-            if kwargs['package'] is not None:
-                warning_message = ("Can not test .rst docs for {name}, since "
-                                   "docs path ({path}) does not exist.")
-                paths = self.packages_path(kwargs['package'], docs_path,
-                                           warning=warning_message)
-            elif not kwargs['test_path']:
-                paths = [docs_path, ]
+        if docs_path is not None and not kwargs["skip_docs"]:
+            if kwargs["package"] is not None:
+                warning_message = (
+                    "Can not test .rst docs for {name}, since "
+                    "docs path ({path}) does not exist."
+                )
+                paths = self.packages_path(
+                    kwargs["package"], docs_path, warning=warning_message
+                )
+            elif not kwargs["test_path"]:
+                paths = [docs_path]
 
-            if len(paths) and not kwargs['test_path']:
-                paths.append('--doctest-rst')
+            if len(paths) and not kwargs["test_path"]:
+                paths.append("--doctest-rst")
 
         return paths
 
@@ -596,16 +610,15 @@ class TestRunner(TestRunnerBase):
             useful for diagnosing sporadic failures.
         """
         if repeat:
-            return [f'--repeat={repeat}']
+            return [f"--repeat={repeat}"]
 
         return []
 
     # Override run_tests for astropy-specific fixes
     def run_tests(self, **kwargs):
-
         # This prevents cyclical import problems that make it
         # impossible to test packages that define Table types on their
         # own.
-        from astropy.table import Table  # pylint: disable=W0611
+        from astropy.table import Table  # noqa: F401
 
         return super().run_tests(**kwargs)
