@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 __all__ = ["BoxLeastSquares", "BoxLeastSquaresResults"]
@@ -6,11 +5,12 @@ __all__ = ["BoxLeastSquares", "BoxLeastSquaresResults"]
 import numpy as np
 
 from astropy import units
-from astropy.time import Time, TimeDelta
-from astropy.timeseries.periodograms.lombscargle.core import has_units, strip_units
 from astropy import units as u
-from . import methods
+from astropy.time import Time, TimeDelta
 from astropy.timeseries.periodograms.base import BasePeriodogram
+from astropy.timeseries.periodograms.lombscargle.core import has_units, strip_units
+
+from . import methods
 
 
 def validate_unit_consistency(reference_object, input_object):
@@ -33,22 +33,22 @@ class BoxLeastSquares(BasePeriodogram):
 
     Parameters
     ----------
-    t : array_like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
+    t : array-like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
         Sequence of observation times.
-    y : array_like or `~astropy.units.Quantity`
+    y : array-like or `~astropy.units.Quantity`
         Sequence of observations associated with times ``t``.
-    dy : float, array_like, or `~astropy.units.Quantity`, optional
+    dy : float, array-like, or `~astropy.units.Quantity`, optional
         Error or sequence of observational errors associated with times ``t``.
 
     Examples
     --------
     Generate noisy data with a transit:
 
-    >>> rand = np.random.RandomState(42)
+    >>> rand = np.random.default_rng(42)
     >>> t = rand.uniform(0, 10, 500)
     >>> y = np.ones_like(t)
     >>> y[np.abs((t + 1.0)%2.0-1)<0.08] = 1.0 - 0.1
-    >>> y += 0.01 * rand.randn(len(t))
+    >>> y += 0.01 * rand.standard_normal(len(t))
 
     Compute the transit periodogram on a heuristically determined period grid
     and find the period with maximum power:
@@ -56,14 +56,14 @@ class BoxLeastSquares(BasePeriodogram):
     >>> model = BoxLeastSquares(t, y)
     >>> results = model.autopower(0.16)
     >>> results.period[np.argmax(results.power)]  # doctest: +FLOAT_CMP
-    1.9923406038842544
+    2.000412388152837
 
     Compute the periodogram on a user-specified period grid:
 
     >>> periods = np.linspace(1.9, 2.1, 5)
     >>> results = model.power(periods, 0.16)
     >>> results.power  # doctest: +FLOAT_CMP
-    array([0.01421067, 0.02842475, 0.10867671, 0.05117755, 0.01783253])
+    array([0.01723948, 0.0643028 , 0.1338783 , 0.09428816, 0.03577543])
 
     If the inputs are AstroPy Quantities with units, the units will be
     validated and the outputs will also be Quantities with appropriate units:
@@ -88,12 +88,11 @@ class BoxLeastSquares(BasePeriodogram):
     """
 
     def __init__(self, t, y, dy=None):
-
         # If t is a TimeDelta, convert it to a quantity. The units we convert
         # to don't really matter since the user gets a Quantity back at the end
         # so can convert to any units they like.
         if isinstance(t, TimeDelta):
-            t = t.to('day')
+            t = t.to("day")
 
         # We want to expose self.t as being the times the user passed in, but
         # if the times are absolute, we need to convert them to relative times
@@ -101,7 +100,7 @@ class BoxLeastSquares(BasePeriodogram):
 
         self.t = t
 
-        if isinstance(self.t, Time):
+        if isinstance(self.t, (Time, TimeDelta)):
             self._tstart = self.t[0]
             trel = (self.t - self._tstart).to(u.day)
         else:
@@ -110,9 +109,14 @@ class BoxLeastSquares(BasePeriodogram):
 
         self._trel, self.y, self.dy = self._validate_inputs(trel, y, dy)
 
-    def autoperiod(self, duration,
-                   minimum_period=None, maximum_period=None,
-                   minimum_n_transit=3, frequency_factor=1.0):
+    def autoperiod(
+        self,
+        duration,
+        minimum_period=None,
+        maximum_period=None,
+        minimum_n_transit=3,
+        frequency_factor=1.0,
+    ):
         """Determine a suitable grid of periods
 
         This method uses a set of heuristics to select a conservative period
@@ -123,12 +127,12 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations that will be considered.
-        minimum_period, maximum_period : float or `~astropy.units.Quantity`, optional
+        minimum_period, maximum_period : float or `~astropy.units.Quantity` ['time'], optional
             The minimum/maximum periods to search. If not provided, these will
             be computed as described in the notes below.
-        minimum_n_transits : int, optional
+        minimum_n_transit : int, optional
             If ``maximum_period`` is not provided, this is used to compute the
             maximum period to search by asserting that any systems with at
             least ``minimum_n_transits`` will be within the range of searched
@@ -141,7 +145,7 @@ class BoxLeastSquares(BasePeriodogram):
 
         Returns
         -------
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The set of periods computed using these heuristics with the same
             units as ``t``.
 
@@ -195,7 +199,7 @@ class BoxLeastSquares(BasePeriodogram):
         if maximum_period is None:
             if minimum_n_transit <= 1:
                 raise ValueError("minimum_n_transit must be greater than 1")
-            maximum_period = baseline / (minimum_n_transit-1)
+            maximum_period = baseline / (minimum_n_transit - 1)
         else:
             maximum_period = validate_unit_consistency(self._trel, maximum_period)
             maximum_period = strip_units(maximum_period)
@@ -206,16 +210,24 @@ class BoxLeastSquares(BasePeriodogram):
             raise ValueError("minimum_period must be positive")
 
         # Convert bounds to frequency
-        minimum_frequency = 1.0/strip_units(maximum_period)
-        maximum_frequency = 1.0/strip_units(minimum_period)
+        minimum_frequency = 1.0 / strip_units(maximum_period)
+        maximum_frequency = 1.0 / strip_units(minimum_period)
 
         # Compute the number of frequencies and the frequency grid
-        nf = 1 + int(np.round((maximum_frequency - minimum_frequency)/df))
-        return 1.0/(maximum_frequency-df*np.arange(nf)) * self._t_unit()
+        nf = 1 + int(np.round((maximum_frequency - minimum_frequency) / df))
+        return 1.0 / (maximum_frequency - df * np.arange(nf)) * self._t_unit()
 
-    def autopower(self, duration, objective=None, method=None, oversample=10,
-                  minimum_n_transit=3, minimum_period=None,
-                  maximum_period=None, frequency_factor=1.0):
+    def autopower(
+        self,
+        duration,
+        objective=None,
+        method=None,
+        oversample=10,
+        minimum_n_transit=3,
+        minimum_period=None,
+        maximum_period=None,
+        frequency_factor=1.0,
+    ):
         """Compute the periodogram at set of heuristically determined periods
 
         This method calls :func:`BoxLeastSquares.autoperiod` to determine
@@ -223,23 +235,25 @@ class BoxLeastSquares(BasePeriodogram):
         the periodogram. See those methods for documentation of the arguments.
 
         """
-        period = self.autoperiod(duration,
-                                 minimum_n_transit=minimum_n_transit,
-                                 minimum_period=minimum_period,
-                                 maximum_period=maximum_period,
-                                 frequency_factor=frequency_factor)
-        return self.power(period, duration, objective=objective, method=method,
-                          oversample=oversample)
+        period = self.autoperiod(
+            duration,
+            minimum_n_transit=minimum_n_transit,
+            minimum_period=minimum_period,
+            maximum_period=maximum_period,
+            frequency_factor=frequency_factor,
+        )
+        return self.power(
+            period, duration, objective=objective, method=method, oversample=oversample
+        )
 
-    def power(self, period, duration, objective=None, method=None,
-              oversample=10):
+    def power(self, period, duration, objective=None, method=None, oversample=10):
         """Compute the periodogram for a set of periods
 
         Parameters
         ----------
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The periods where the power should be computed
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations to test
         objective : {'likelihood', 'snr'}, optional
             The scalar that should be optimized to find the best fit phase,
@@ -277,8 +291,7 @@ class BoxLeastSquares(BasePeriodogram):
         try:
             oversample = int(oversample)
         except TypeError:
-            raise ValueError("oversample must be an int, got {}"
-                             .format(oversample))
+            raise ValueError(f"oversample must be an int, got {oversample}")
         if oversample < 1:
             raise ValueError("oversample must be greater than or equal to 1")
 
@@ -287,19 +300,21 @@ class BoxLeastSquares(BasePeriodogram):
             objective = "likelihood"
         allowed_objectives = ["snr", "likelihood"]
         if objective not in allowed_objectives:
-            raise ValueError(("Unrecognized method '{0}'\n"
-                              "allowed methods are: {1}")
-                             .format(objective, allowed_objectives))
-        use_likelihood = (objective == "likelihood")
+            raise ValueError(
+                f"Unrecognized method '{objective}'\n"
+                f"allowed methods are: {allowed_objectives}"
+            )
+        use_likelihood = objective == "likelihood"
 
         # Select the computational method
         if method is None:
             method = "fast"
         allowed_methods = ["fast", "slow"]
         if method not in allowed_methods:
-            raise ValueError(("Unrecognized method '{0}'\n"
-                              "allowed methods are: {1}")
-                             .format(method, allowed_methods))
+            raise ValueError(
+                f"Unrecognized method '{method}'\n"
+                f"allowed methods are: {allowed_methods}"
+            )
 
         # Format and check the input arrays
         t = np.ascontiguousarray(strip_units(self._trel), dtype=np.float64)
@@ -308,14 +323,13 @@ class BoxLeastSquares(BasePeriodogram):
         if self.dy is None:
             ivar = np.ones_like(y)
         else:
-            ivar = 1.0 / np.ascontiguousarray(strip_units(self.dy),
-                                              dtype=np.float64)**2
+            ivar = (
+                1.0 / np.ascontiguousarray(strip_units(self.dy), dtype=np.float64) ** 2
+            )
 
         # Make sure that the period and duration arrays are C-order
-        period_fmt = np.ascontiguousarray(strip_units(period),
-                                          dtype=np.float64)
-        duration = np.ascontiguousarray(strip_units(duration),
-                                        dtype=np.float64)
+        period_fmt = np.ascontiguousarray(strip_units(period), dtype=np.float64)
+        duration = np.ascontiguousarray(strip_units(duration), dtype=np.float64)
 
         # Select the correct implementation for the chosen method
         if method == "fast":
@@ -325,8 +339,14 @@ class BoxLeastSquares(BasePeriodogram):
 
         # Run the implementation
         results = bls(
-            t - t_ref, y - np.median(y), ivar, period_fmt, duration,
-            oversample, use_likelihood)
+            t - t_ref,
+            y - np.median(y),
+            ivar,
+            period_fmt,
+            duration,
+            oversample,
+            use_likelihood,
+        )
 
         return self._format_results(t_ref, objective, period, results)
 
@@ -338,20 +358,24 @@ class BoxLeastSquares(BasePeriodogram):
         """
 
         if isinstance(times, TimeDelta):
-            times = times.to('day')
+            times = times.to("day")
 
         if self._tstart is None:
             if isinstance(times, Time):
-                raise TypeError('{} was provided as an absolute time but '
-                                'the BoxLeastSquares class was initialized '
-                                'with relative times.'.format(name))
+                raise TypeError(
+                    f"{name} was provided as an absolute time but "
+                    "the BoxLeastSquares class was initialized "
+                    "with relative times."
+                )
         else:
             if isinstance(times, Time):
                 times = (times - self._tstart).to(u.day)
             else:
-                raise TypeError('{} was provided as a relative time but '
-                                'the BoxLeastSquares class was initialized '
-                                'with absolute times.'.format(name))
+                raise TypeError(
+                    f"{name} was provided as a relative time but "
+                    "the BoxLeastSquares class was initialized "
+                    "with absolute times."
+                )
 
         times = validate_unit_consistency(self._trel, times)
 
@@ -378,26 +402,26 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        t_model : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+        t_model : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
             Times at which to compute the model.
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
 
         Returns
         -------
-        y_model : array_like or `~astropy.units.Quantity`
+        y_model : array-like or `~astropy.units.Quantity`
             The model evaluated at the times ``t_model`` with units of ``y``.
 
         """
 
         period, duration = self._validate_period_and_duration(period, duration)
 
-        transit_time = self._as_relative_time('transit_time', transit_time)
-        t_model = strip_units(self._as_relative_time('t_model', t_model))
+        transit_time = self._as_relative_time("transit_time", transit_time)
+        t_model = strip_units(self._as_relative_time("t_model", t_model))
 
         period = float(strip_units(period))
         duration = float(strip_units(duration))
@@ -408,19 +432,20 @@ class BoxLeastSquares(BasePeriodogram):
         if self.dy is None:
             ivar = np.ones_like(y)
         else:
-            ivar = 1.0 / np.ascontiguousarray(strip_units(self.dy),
-                                              dtype=np.float64)**2
+            ivar = (
+                1.0 / np.ascontiguousarray(strip_units(self.dy), dtype=np.float64) ** 2
+            )
 
         # Compute the depth
-        hp = 0.5*period
-        m_in = np.abs((t-transit_time+hp) % period - hp) < 0.5*duration
+        hp = 0.5 * period
+        m_in = np.abs((t - transit_time + hp) % period - hp) < 0.5 * duration
         m_out = ~m_in
         y_in = np.sum(y[m_in] * ivar[m_in]) / np.sum(ivar[m_in])
         y_out = np.sum(y[m_out] * ivar[m_out]) / np.sum(ivar[m_out])
 
         # Evaluate the model
         y_model = y_out + np.zeros_like(t_model)
-        m_model = np.abs((t_model-transit_time+hp) % period-hp) < 0.5*duration
+        m_model = np.abs((t_model - transit_time + hp) % period - hp) < 0.5 * duration
         y_model[m_model] = y_in
 
         return y_model * self._y_unit()
@@ -432,9 +457,9 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
@@ -472,7 +497,7 @@ class BoxLeastSquares(BasePeriodogram):
         """
 
         period, duration = self._validate_period_and_duration(period, duration)
-        transit_time = self._as_relative_time('transit_time', transit_time)
+        transit_time = self._as_relative_time("transit_time", transit_time)
 
         period = float(strip_units(period))
         duration = float(strip_units(duration))
@@ -483,8 +508,9 @@ class BoxLeastSquares(BasePeriodogram):
         if self.dy is None:
             ivar = np.ones_like(y)
         else:
-            ivar = 1.0 / np.ascontiguousarray(strip_units(self.dy),
-                                              dtype=np.float64)**2
+            ivar = (
+                1.0 / np.ascontiguousarray(strip_units(self.dy), dtype=np.float64) ** 2
+            )
 
         # This a helper function that will compute the depth for several
         # different hypothesized transit models with different parameters
@@ -499,13 +525,13 @@ class BoxLeastSquares(BasePeriodogram):
 
         # Compute the depth of the fiducial model and the two models at twice
         # the period
-        hp = 0.5*period
-        m_in = np.abs((t-transit_time+hp) % period - hp) < 0.5*duration
+        hp = 0.5 * period
+        m_in = np.abs((t - transit_time + hp) % period - hp) < 0.5 * duration
         m_out = ~m_in
-        m_odd = np.abs((t-transit_time) % (2*period) - period) \
-            < 0.5*duration
-        m_even = np.abs((t-transit_time+period) % (2*period) - period) \
-            < 0.5*duration
+        m_odd = np.abs((t - transit_time) % (2 * period) - period) < 0.5 * duration
+        m_even = (
+            np.abs((t - transit_time + period) % (2 * period) - period) < 0.5 * duration
+        )
 
         y_out, var_out = _compute_depth(m_out)
         depth = _compute_depth(m_in, y_out, var_out)
@@ -514,43 +540,46 @@ class BoxLeastSquares(BasePeriodogram):
         y_in = y_out - depth[0]
 
         # Compute the depth of the model at a phase of 0.5*period
-        m_phase = np.abs((t-transit_time) % period - hp) < 0.5*duration
-        depth_phase = _compute_depth(m_phase,
-                                     *_compute_depth((~m_phase) & m_out))
+        m_phase = np.abs((t - transit_time) % period - hp) < 0.5 * duration
+        depth_phase = _compute_depth(m_phase, *_compute_depth((~m_phase) & m_out))
 
         # Compute the depth of a model with a period of 0.5*period
-        m_half = np.abs((t-transit_time+0.25*period) % (0.5*period)
-                        - 0.25*period) < 0.5*duration
+        m_half = (
+            np.abs((t - transit_time + 0.25 * period) % (0.5 * period) - 0.25 * period)
+            < 0.5 * duration
+        )
         depth_half = _compute_depth(m_half, *_compute_depth(~m_half))
 
         # Compute the number of points in each transit
-        transit_id = np.round((t[m_in]-transit_time) / period).astype(int)
-        transit_times = period * np.arange(transit_id.min(),
-                                           transit_id.max()+1) + transit_time
-        unique_ids, unique_counts = np.unique(transit_id,
-                                              return_counts=True)
+        transit_id = np.round((t[m_in] - transit_time) / period).astype(int)
+        transit_times = (
+            period * np.arange(transit_id.min(), transit_id.max() + 1) + transit_time
+        )
+        unique_ids, unique_counts = np.unique(transit_id, return_counts=True)
         unique_ids -= np.min(transit_id)
         transit_id -= np.min(transit_id)
         counts = np.zeros(np.max(transit_id) + 1, dtype=int)
         counts[unique_ids] = unique_counts
 
         # Compute the per-transit log likelihood
-        ll = -0.5 * ivar[m_in] * ((y[m_in] - y_in)**2 - (y[m_in] - y_out)**2)
+        ll = -0.5 * ivar[m_in] * ((y[m_in] - y_in) ** 2 - (y[m_in] - y_out) ** 2)
         lls = np.zeros(len(counts))
         for i in unique_ids:
             lls[i] = np.sum(ll[transit_id == i])
-        full_ll = -0.5*np.sum(ivar[m_in] * (y[m_in] - y_in)**2)
-        full_ll -= 0.5*np.sum(ivar[m_out] * (y[m_out] - y_out)**2)
+        full_ll = -0.5 * np.sum(ivar[m_in] * (y[m_in] - y_in) ** 2)
+        full_ll -= 0.5 * np.sum(ivar[m_out] * (y[m_out] - y_out) ** 2)
 
         # Compute the log likelihood of a sine model
-        A = np.vstack((
-            np.sin(2*np.pi*t/period), np.cos(2*np.pi*t/period),
-            np.ones_like(t)
-        )).T
-        w = np.linalg.solve(np.dot(A.T, A * ivar[:, None]),
-                            np.dot(A.T, y * ivar))
+        A = np.vstack(
+            (
+                np.sin(2 * np.pi * t / period),
+                np.cos(2 * np.pi * t / period),
+                np.ones_like(t),
+            )
+        ).T
+        w = np.linalg.solve(np.dot(A.T, A * ivar[:, None]), np.dot(A.T, y * ivar))
         mod = np.dot(A, w)
-        sin_ll = -0.5*np.sum((y-mod)**2*ivar)
+        sin_ll = -0.5 * np.sum((y - mod) ** 2 * ivar)
 
         # Format the results
         y_unit = self._y_unit()
@@ -558,7 +587,9 @@ class BoxLeastSquares(BasePeriodogram):
         if self.dy is None:
             ll_unit = y_unit * y_unit
         return dict(
-            transit_times=self._as_absolute_time_if_needed('transit_times', transit_times * self._t_unit()),
+            transit_times=self._as_absolute_time_if_needed(
+                "transit_times", transit_times * self._t_unit()
+            ),
             per_transit_count=counts,
             per_transit_log_likelihood=lls * ll_unit,
             depth=(depth[0] * y_unit, depth[1] * y_unit),
@@ -566,7 +597,7 @@ class BoxLeastSquares(BasePeriodogram):
             depth_half=(depth_half[0] * y_unit, depth_half[1] * y_unit),
             depth_odd=(depth_odd[0] * y_unit, depth_odd[1] * y_unit),
             depth_even=(depth_even[0] * y_unit, depth_even[1] * y_unit),
-            harmonic_amplitude=np.sqrt(np.sum(w[:2]**2)) * y_unit,
+            harmonic_amplitude=np.sqrt(np.sum(w[:2] ** 2)) * y_unit,
             harmonic_delta_log_likelihood=(sin_ll - full_ll) * ll_unit,
         )
 
@@ -575,49 +606,49 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        t_model : array_like or `~astropy.units.Quantity`
+        t : array-like or `~astropy.units.Quantity` ['time']
             Times where the mask should be evaluated.
-        period : float or `~astropy.units.Quantity`
+        period : float or `~astropy.units.Quantity` ['time']
             The period of the transits.
-        duration : float or `~astropy.units.Quantity`
+        duration : float or `~astropy.units.Quantity` ['time']
             The duration of the transit.
         transit_time : float or `~astropy.units.Quantity` or `~astropy.time.Time`
             The mid-transit time of a reference transit.
 
         Returns
         -------
-        transit_mask : array_like
+        transit_mask : array-like
             A boolean array where ``True`` indicates and in transit point and
             ``False`` indicates and out-of-transit point.
 
         """
 
         period, duration = self._validate_period_and_duration(period, duration)
-        transit_time = self._as_relative_time('transit_time', transit_time)
-        t = strip_units(self._as_relative_time('t', t))
+        transit_time = self._as_relative_time("transit_time", transit_time)
+        t = strip_units(self._as_relative_time("t", t))
 
         period = float(strip_units(period))
         duration = float(strip_units(duration))
         transit_time = float(strip_units(transit_time))
 
-        hp = 0.5*period
-        return np.abs((t-transit_time+hp) % period - hp) < 0.5*duration
+        hp = 0.5 * period
+        return np.abs((t - transit_time + hp) % period - hp) < 0.5 * duration
 
     def _validate_inputs(self, t, y, dy):
         """Private method used to check the consistency of the inputs
 
         Parameters
         ----------
-        t : array_like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
+        t : array-like, `~astropy.units.Quantity`, `~astropy.time.Time`, or `~astropy.time.TimeDelta`
             Sequence of observation times.
-        y : array_like or `~astropy.units.Quantity`
+        y : array-like or `~astropy.units.Quantity`
             Sequence of observations associated with times t.
-        dy : float, array_like, or `~astropy.units.Quantity`
+        dy : float, array-like, or `~astropy.units.Quantity`
             Error or sequence of observational errors associated with times t.
 
         Returns
         -------
-        t, y, dy : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+        t, y, dy : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
             The inputs with consistent shapes and units.
 
         Raises
@@ -647,12 +678,12 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity`
             The set of durations that will be considered.
 
         Returns
         -------
-        duration : array_like or `~astropy.units.Quantity`
+        duration : array-like or `~astropy.units.Quantity`
             The input reformatted with the correct shape and units.
 
         Raises
@@ -671,14 +702,14 @@ class BoxLeastSquares(BasePeriodogram):
 
         Parameters
         ----------
-        period : float, array_like, or `~astropy.units.Quantity`
+        period : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of test periods.
-        duration : float, array_like, or `~astropy.units.Quantity`
+        duration : float, array-like, or `~astropy.units.Quantity` ['time']
             The set of durations that will be considered.
 
         Returns
         -------
-        period, duration : array_like or `~astropy.units.Quantity`
+        period, duration : array-like or `~astropy.units.Quantity` ['time']
             The inputs reformatted with the correct shapes and units.
 
         Raises
@@ -695,8 +726,9 @@ class BoxLeastSquares(BasePeriodogram):
         period = validate_unit_consistency(self._trel, period)
 
         if not np.min(period) > np.max(duration):
-            raise ValueError("The maximum transit duration must be shorter "
-                             "than the minimum period")
+            raise ValueError(
+                "The maximum transit duration must be shorter than the minimum period"
+            )
 
         return period, duration
 
@@ -709,19 +741,28 @@ class BoxLeastSquares(BasePeriodogram):
             The minimum time in the time series (a reference time).
         objective : str
             The name of the objective used in the optimization.
-        period : array_like or `~astropy.units.Quantity`
+        period : array-like or `~astropy.units.Quantity` ['time']
             The set of trial periods.
         results : tuple
             The output of one of the periodogram implementations.
 
         """
-        (power, depth, depth_err, duration, transit_time, depth_snr,
-         log_likelihood) = results
+        (
+            power,
+            depth,
+            depth_err,
+            duration,
+            transit_time,
+            depth_snr,
+            log_likelihood,
+        ) = results
         transit_time += t_ref
 
         if has_units(self._trel):
             transit_time = units.Quantity(transit_time, unit=self._trel.unit)
-            transit_time = self._as_absolute_time_if_needed('transit_time', transit_time)
+            transit_time = self._as_absolute_time_if_needed(
+                "transit_time", transit_time
+            )
             duration = units.Quantity(duration, unit=self._trel.unit)
 
         if has_units(self.y):
@@ -735,15 +776,22 @@ class BoxLeastSquares(BasePeriodogram):
                     power = units.Quantity(power, unit=self.y.unit**2)
                 else:
                     power = units.Quantity(power, unit=units.one)
-                log_likelihood = units.Quantity(log_likelihood,
-                                                unit=self.y.unit**2)
+                log_likelihood = units.Quantity(log_likelihood, unit=self.y.unit**2)
             else:
                 power = units.Quantity(power, unit=units.one)
                 log_likelihood = units.Quantity(log_likelihood, unit=units.one)
 
         return BoxLeastSquaresResults(
-            objective, period, power, depth, depth_err, duration, transit_time,
-            depth_snr, log_likelihood)
+            objective,
+            period,
+            power,
+            depth,
+            depth_err,
+            duration,
+            transit_time,
+            depth_snr,
+            log_likelihood,
+        )
 
     def _t_unit(self):
         if has_units(self._trel):
@@ -766,9 +814,9 @@ class BoxLeastSquaresResults(dict):
     objective : str
         The scalar used to optimize to find the best fit phase, duration, and
         depth. See :func:`BoxLeastSquares.power` for more information.
-    period : array_like or `~astropy.units.Quantity`
+    period : array-like or `~astropy.units.Quantity` ['time']
         The set of test periods.
-    power : array_like or `~astropy.units.Quantity`
+    power : array-like or `~astropy.units.Quantity`
         The periodogram evaluated at the periods in ``period``. If
         ``objective`` is:
 
@@ -778,28 +826,40 @@ class BoxLeastSquaresResults(dict):
           which the depth is measured maximized over phase, depth, and
           duration.
 
-    depth : array_like or `~astropy.units.Quantity`
+    depth : array-like or `~astropy.units.Quantity`
         The estimated depth of the maximum power model at each period.
-    depth_err : array_like or `~astropy.units.Quantity`
+    depth_err : array-like or `~astropy.units.Quantity`
         The 1-sigma uncertainty on ``depth``.
-    duration : array_like or `~astropy.units.Quantity`
+    duration : array-like or `~astropy.units.Quantity` ['time']
         The maximum power duration at each period.
-    transit_time : array_like, `~astropy.units.Quantity`, or `~astropy.time.Time`
+    transit_time : array-like, `~astropy.units.Quantity`, or `~astropy.time.Time`
         The maximum power phase of the transit in units of time. This
         indicates the mid-transit time and it will always be in the range
         (0, period).
-    depth_snr : array_like or `~astropy.units.Quantity`
+    depth_snr : array-like or `~astropy.units.Quantity`
         The signal-to-noise with which the depth is measured at maximum power.
-    log_likelihood : array_like or `~astropy.units.Quantity`
+    log_likelihood : array-like or `~astropy.units.Quantity`
         The log likelihood of the maximum power model.
 
     """
+
     def __init__(self, *args):
-        super().__init__(zip(
-            ("objective", "period", "power", "depth", "depth_err",
-             "duration", "transit_time", "depth_snr", "log_likelihood"),
-            args
-        ))
+        super().__init__(
+            zip(
+                (
+                    "objective",
+                    "period",
+                    "power",
+                    "depth",
+                    "depth_err",
+                    "duration",
+                    "transit_time",
+                    "depth_snr",
+                    "log_likelihood",
+                ),
+                args,
+            )
+        )
 
     def __getattr__(self, name):
         try:
@@ -813,8 +873,9 @@ class BoxLeastSquaresResults(dict):
     def __repr__(self):
         if self.keys():
             m = max(map(len, list(self.keys()))) + 1
-            return '\n'.join([k.rjust(m) + ': ' + repr(v)
-                              for k, v in sorted(self.items())])
+            return "\n".join(
+                [k.rjust(m) + ": " + repr(v) for k, v in sorted(self.items())]
+            )
         else:
             return self.__class__.__name__ + "()"
 
