@@ -1,4 +1,3 @@
-
 import numpy as np
 
 
@@ -53,8 +52,7 @@ def design_matrix(t, frequency, dy=None, bias=True, nterms=1):
     return np.transpose(XT)
 
 
-def periodic_fit(t, y, dy, frequency, t_fit,
-                 center_data=True, fit_mean=True, nterms=1):
+def periodic_fit(t, y, dy, frequency, t_fit, center_data=True, fit_mean=True, nterms=1):
     """Compute the Lomb-Scargle model fit at a given frequency
 
     Parameters
@@ -93,15 +91,14 @@ def periodic_fit(t, y, dy, frequency, t_fit,
         raise ValueError("frequency should be a scalar")
 
     if center_data:
-        w = dy ** -2.0
+        w = dy**-2.0
         y_mean = np.dot(y, w) / w.sum()
-        y = (y - y_mean)
+        y = y - y_mean
     else:
         y_mean = 0
 
     X = design_matrix(t, frequency, dy=dy, bias=fit_mean, nterms=nterms)
-    theta_MLE = np.linalg.solve(np.dot(X.T, X),
-                                np.dot(X.T, y / dy))
+    theta_MLE = np.linalg.solve(np.dot(X.T, X), np.dot(X.T, y / dy))
 
     X_fit = design_matrix(t_fit, frequency, bias=fit_mean, nterms=nterms)
 
