@@ -1,26 +1,25 @@
-# -*- coding: utf-8 -*-
-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import gc
 import locale
 import re
-from distutils.version import LooseVersion
 
-import pytest
 import numpy as np
-from numpy.testing import assert_array_equal, assert_array_almost_equal
+import pytest
+from numpy.testing import assert_array_almost_equal, assert_array_equal
+from packaging.version import Version
 
-from astropy.tests.helper import raises, catch_warnings
-from astropy.io import fits
-from astropy.wcs import wcs
-from astropy.wcs import _wcs
-from astropy.wcs.wcs import FITSFixedWarning
-from astropy.utils.data import (
-    get_pkg_data_contents, get_pkg_data_fileobj, get_pkg_data_filename)
-from astropy.utils.misc import _set_locale
 from astropy import units as u
+from astropy.io import fits
 from astropy.units.core import UnitsWarning
+from astropy.utils.data import (
+    get_pkg_data_contents,
+    get_pkg_data_filename,
+    get_pkg_data_fileobj,
+)
+from astropy.utils.misc import _set_locale
+from astropy.wcs import _wcs, wcs
+from astropy.wcs.wcs import FITSFixedWarning
 
 ######################################################################
 
@@ -34,16 +33,16 @@ def test_alt():
     assert w.alt == " "
 
 
-@raises(ValueError)
 def test_alt_invalid1():
     w = _wcs.Wcsprm()
-    w.alt = "$"
+    with pytest.raises(ValueError):
+        w.alt = "$"
 
 
-@raises(ValueError)
 def test_alt_invalid2():
     w = _wcs.Wcsprm()
-    w.alt = "  "
+    with pytest.raises(ValueError):
+        w.alt = "  "
 
 
 def test_axis_types():
@@ -61,27 +60,27 @@ def test_cd():
     assert w.has_cd() is False
 
 
-@raises(AttributeError)
 def test_cd_missing():
     w = _wcs.Wcsprm()
     assert w.has_cd() is False
-    w.cd
+    with pytest.raises(AttributeError):
+        w.cd
 
 
-@raises(AttributeError)
 def test_cd_missing2():
     w = _wcs.Wcsprm()
     w.cd = [[1, 0], [0, 1]]
     assert w.has_cd() is True
     del w.cd
     assert w.has_cd() is False
-    w.cd
+    with pytest.raises(AttributeError):
+        w.cd
 
 
-@raises(ValueError)
 def test_cd_invalid():
     w = _wcs.Wcsprm()
-    w.cd = [1, 0, 0, 1]
+    with pytest.raises(ValueError):
+        w.cd = [1, 0, 0, 1]
 
 
 def test_cdfix():
@@ -96,16 +95,16 @@ def test_cdelt():
     assert_array_equal(w.cdelt, [42, 54])
 
 
-@raises(TypeError)
 def test_cdelt_delete():
     w = _wcs.Wcsprm()
-    del w.cdelt
+    with pytest.raises(TypeError):
+        del w.cdelt
 
 
 def test_cel_offset():
     w = _wcs.Wcsprm()
     assert w.cel_offset is False
-    w.cel_offset = 'foo'
+    w.cel_offset = "foo"
     assert w.cel_offset is True
     w.cel_offset = 0
     assert w.cel_offset is False
@@ -122,16 +121,16 @@ def test_cname():
     w = _wcs.Wcsprm()
     # Test that this works as an iterator
     for x in w.cname:
-        assert x == ''
-    assert list(w.cname) == ['', '']
-    w.cname = [b'foo', 'bar']
-    assert list(w.cname) == ['foo', 'bar']
+        assert x == ""
+    assert list(w.cname) == ["", ""]
+    w.cname = [b"foo", "bar"]
+    assert list(w.cname) == ["foo", "bar"]
 
 
-@raises(TypeError)
 def test_cname_invalid():
     w = _wcs.Wcsprm()
-    w.cname = [42, 54]
+    with pytest.raises(TypeError):
+        w.cname = [42, 54]
 
 
 def test_colax():
@@ -154,19 +153,19 @@ def test_colnum():
     assert w.colnum == 42
 
     with pytest.raises(OverflowError):
-        w.colnum = 0xffffffffffffffffffff
+        w.colnum = 0xFFFFFFFFFFFFFFFFFFFF
 
     with pytest.raises(OverflowError):
-        w.colnum = 0xffffffff
+        w.colnum = 0xFFFFFFFF
 
     with pytest.raises(TypeError):
         del w.colnum
 
 
-@raises(TypeError)
 def test_colnum_invalid():
     w = _wcs.Wcsprm()
-    w.colnum = 'foo'
+    with pytest.raises(TypeError):
+        w.colnum = "foo"
 
 
 def test_crder():
@@ -189,21 +188,21 @@ def test_crota():
     assert w.has_crota() is False
 
 
-@raises(AttributeError)
 def test_crota_missing():
     w = _wcs.Wcsprm()
     assert w.has_crota() is False
-    w.crota
+    with pytest.raises(AttributeError):
+        w.crota
 
 
-@raises(AttributeError)
 def test_crota_missing2():
     w = _wcs.Wcsprm()
     w.crota = [1, 0]
     assert w.has_crota() is True
     del w.crota
     assert w.has_crota() is False
-    w.crota
+    with pytest.raises(AttributeError):
+        w.crota
 
 
 def test_crpix():
@@ -241,55 +240,55 @@ def test_csyer():
 
 def test_ctype():
     w = _wcs.Wcsprm()
-    assert list(w.ctype) == ['', '']
-    w.ctype = [b'RA---TAN', 'DEC--TAN']
+    assert list(w.ctype) == ["", ""]
+    w.ctype = [b"RA---TAN", "DEC--TAN"]
     assert_array_equal(w.axis_types, [2200, 2201])
     assert w.lat == 1
     assert w.lng == 0
-    assert w.lattyp == 'DEC'
-    assert w.lngtyp == 'RA'
-    assert list(w.ctype) == ['RA---TAN', 'DEC--TAN']
-    w.ctype = ['foo', 'bar']
+    assert w.lattyp == "DEC"
+    assert w.lngtyp == "RA"
+    assert list(w.ctype) == ["RA---TAN", "DEC--TAN"]
+    w.ctype = ["foo", "bar"]
     assert_array_equal(w.axis_types, [0, 0])
-    assert list(w.ctype) == ['foo', 'bar']
+    assert list(w.ctype) == ["foo", "bar"]
     assert w.lat == -1
     assert w.lng == -1
-    assert w.lattyp == 'DEC'
-    assert w.lngtyp == 'RA'
+    assert w.lattyp == "DEC"
+    assert w.lngtyp == "RA"
 
 
 def test_ctype_repr():
     w = _wcs.Wcsprm()
-    assert list(w.ctype) == ['', '']
-    w.ctype = [b'RA-\t--TAN', 'DEC-\n-TAN']
+    assert list(w.ctype) == ["", ""]
+    w.ctype = [b"RA-\t--TAN", "DEC-\n-TAN"]
     assert repr(w.ctype == '["RA-\t--TAN", "DEC-\n-TAN"]')
 
 
 def test_ctype_index_error():
     w = _wcs.Wcsprm()
-    assert list(w.ctype) == ['', '']
+    assert list(w.ctype) == ["", ""]
     for idx in (2, -3):
         with pytest.raises(IndexError):
             w.ctype[idx]
         with pytest.raises(IndexError):
-            w.ctype[idx] = 'FOO'
+            w.ctype[idx] = "FOO"
 
 
 def test_ctype_invalid_error():
     w = _wcs.Wcsprm()
-    assert list(w.ctype) == ['', '']
+    assert list(w.ctype) == ["", ""]
     with pytest.raises(ValueError):
-        w.ctype[0] = 'X' * 100
+        w.ctype[0] = "X" * 100
     with pytest.raises(TypeError):
         w.ctype[0] = True
     with pytest.raises(TypeError):
-        w.ctype = ['a', 0]
+        w.ctype = ["a", 0]
     with pytest.raises(TypeError):
         w.ctype = None
     with pytest.raises(ValueError):
-        w.ctype = ['a', 'b', 'c']
+        w.ctype = ["a", "b", "c"]
     with pytest.raises(ValueError):
-        w.ctype = ['FOO', 'A' * 100]
+        w.ctype = ["FOO", "A" * 100]
 
 
 def test_cubeface():
@@ -302,27 +301,26 @@ def test_cubeface():
 
 def test_cunit():
     w = _wcs.Wcsprm()
-    assert list(w.cunit) == [u.Unit(''), u.Unit('')]
-    w.cunit = [u.m, 'km']
+    assert list(w.cunit) == [u.Unit(""), u.Unit("")]
+    w.cunit = [u.m, "km"]
     assert w.cunit[0] == u.m
     assert w.cunit[1] == u.km
 
 
 def test_cunit_invalid():
     w = _wcs.Wcsprm()
-    with catch_warnings() as warns:
-        w.cunit[0] = 'foo'
+    with pytest.warns(u.UnitsWarning, match="foo") as warns:
+        w.cunit[0] = "foo"
     assert len(warns) == 1
-    assert 'foo' in str(warns[0].message)
 
 
 def test_cunit_invalid2():
     w = _wcs.Wcsprm()
-    with catch_warnings() as warns:
-        w.cunit = ['foo', 'bar']
+    with pytest.warns(u.UnitsWarning) as warns:
+        w.cunit = ["foo", "bar"]
     assert len(warns) == 2
-    assert 'foo' in str(warns[0].message)
-    assert 'bar' in str(warns[1].message)
+    assert "foo" in str(warns[0].message)
+    assert "bar" in str(warns[1].message)
 
 
 def test_unit():
@@ -370,21 +368,21 @@ def test_cylfix():
 
 def test_dateavg():
     w = _wcs.Wcsprm()
-    assert w.dateavg == ''
+    assert w.dateavg == ""
     # TODO: When dateavg is verified, check that it works
 
 
 def test_dateobs():
     w = _wcs.Wcsprm()
-    assert w.dateobs == ''
+    assert w.dateobs == ""
     # TODO: When dateavg is verified, check that it works
 
 
 def test_datfix():
     w = _wcs.Wcsprm()
-    w.dateobs = '31/12/99'
+    w.dateobs = "31/12/99"
     assert w.datfix() == 0
-    assert w.dateobs == '1999-12-31'
+    assert w.dateobs == "1999-12-31"
     assert w.mjdobs == 51543.0
 
 
@@ -403,81 +401,100 @@ def test_equinox():
 def test_fix():
     w = _wcs.Wcsprm()
     fix_ref = {
-        'cdfix': 'No change',
-        'cylfix': 'No change',
-        'obsfix': 'No change',
-        'datfix': 'No change',
-        'spcfix': 'No change',
-        'unitfix': 'No change',
-        'celfix': 'No change',
-        'obsfix': 'No change'}
+        "cdfix": "No change",
+        "cylfix": "No change",
+        "obsfix": "No change",
+        "datfix": "No change",
+        "spcfix": "No change",
+        "unitfix": "No change",
+        "celfix": "No change",
+        "obsfix": "No change",
+    }
+
     version = wcs._wcs.__version__
-    if LooseVersion(version) <= '5':
-        del fix_ref['obsfix']
-    if LooseVersion(version) >= '7.1':
-        w.dateref = '1858-11-17'
+    if Version(version) <= Version("5"):
+        del fix_ref["obsfix"]
+
+    if Version(version) >= Version("7.1"):
+        w.dateref = "1858-11-17"
+
+    if Version("7.4") <= Version(version) < Version("7.6"):
+        fix_ref["datfix"] = "Success"
+
     assert w.fix() == fix_ref
 
 
 def test_fix2():
     w = _wcs.Wcsprm()
-    w.dateobs = '31/12/99'
+    w.dateobs = "31/12/99"
     fix_ref = {
-        'cdfix': 'No change',
-        'cylfix': 'No change',
-        'obsfix': 'No change',
-        'datfix': "Set MJD-OBS to 51543.000000 from DATE-OBS.\nChanged DATE-OBS from '31/12/99' to '1999-12-31'",  # noqa
-        'spcfix': 'No change',
-        'unitfix': 'No change',
-        'celfix': 'No change'}
+        "cdfix": "No change",
+        "cylfix": "No change",
+        "obsfix": "No change",
+        "datfix": (
+            "Set MJD-OBS to 51543.000000 from DATE-OBS.\n"
+            "Changed DATE-OBS from '31/12/99' to '1999-12-31'"
+        ),
+        "spcfix": "No change",
+        "unitfix": "No change",
+        "celfix": "No change",
+    }
     version = wcs._wcs.__version__
-    if LooseVersion(version) <= "5":
-        del fix_ref['obsfix']
-        fix_ref['datfix'] = "Changed '31/12/99' to '1999-12-31'"
+    if Version(version) <= Version("5"):
+        del fix_ref["obsfix"]
+        fix_ref["datfix"] = "Changed '31/12/99' to '1999-12-31'"
 
-    if LooseVersion(version) >= '7.3':
-        fix_ref['datfix'] = "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref['datfix']
+    if Version(version) >= Version("7.3"):
+        fix_ref["datfix"] = (
+            "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref["datfix"]
+        )
 
-    elif LooseVersion(version) >= '7.1':
-        fix_ref['datfix'] = "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref['datfix']
+    elif Version(version) >= Version("7.1"):
+        fix_ref["datfix"] = (
+            "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref["datfix"]
+        )
 
     assert w.fix() == fix_ref
-    assert w.dateobs == '1999-12-31'
+    assert w.dateobs == "1999-12-31"
     assert w.mjdobs == 51543.0
 
 
 def test_fix3():
     w = _wcs.Wcsprm()
-    w.dateobs = '31/12/F9'
+    w.dateobs = "31/12/F9"
     fix_ref = {
-        'cdfix': 'No change',
-        'cylfix': 'No change',
-        'obsfix': 'No change',
-        'datfix': "Invalid DATE-OBS format '31/12/F9'",
-        'spcfix': 'No change',
-        'unitfix': 'No change',
-        'celfix': 'No change'
+        "cdfix": "No change",
+        "cylfix": "No change",
+        "obsfix": "No change",
+        "datfix": "Invalid DATE-OBS format '31/12/F9'",
+        "spcfix": "No change",
+        "unitfix": "No change",
+        "celfix": "No change",
     }
 
     version = wcs._wcs.__version__
-    if LooseVersion(version) <= "5":
-        del fix_ref['obsfix']
-        fix_ref['datfix'] = "Invalid parameter value: invalid date '31/12/F9'"
+    if Version(version) <= Version("5"):
+        del fix_ref["obsfix"]
+        fix_ref["datfix"] = "Invalid parameter value: invalid date '31/12/F9'"
 
-    if LooseVersion(version) >= '7.3':
-        fix_ref['datfix'] = "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref['datfix']
-    elif LooseVersion(version) >= '7.1':
-        fix_ref['datfix'] = "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref['datfix']
+    if Version(version) >= Version("7.3"):
+        fix_ref["datfix"] = (
+            "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref["datfix"]
+        )
+    elif Version(version) >= Version("7.1"):
+        fix_ref["datfix"] = (
+            "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref["datfix"]
+        )
 
     assert w.fix() == fix_ref
-    assert w.dateobs == '31/12/F9'
+    assert w.dateobs == "31/12/F9"
     assert np.isnan(w.mjdobs)
 
 
 def test_fix4():
     w = _wcs.Wcsprm()
     with pytest.raises(ValueError):
-        w.fix('X')
+        w.fix("X")
 
 
 def test_fix5():
@@ -498,21 +515,21 @@ def test_get_pv():
     assert len(w.get_pv()) == 0
 
 
-@raises(AssertionError)
 def test_imgpix_matrix():
     w = _wcs.Wcsprm()
-    w.imgpix_matrix
+    with pytest.raises(AssertionError):
+        w.imgpix_matrix
 
 
-@raises(AttributeError)
 def test_imgpix_matrix2():
     w = _wcs.Wcsprm()
-    w.imgpix_matrix = None
+    with pytest.raises(AttributeError):
+        w.imgpix_matrix = None
 
 
 def test_isunity():
     w = _wcs.Wcsprm()
-    assert(w.is_unity())
+    assert w.is_unity()
 
 
 def test_lat():
@@ -520,10 +537,10 @@ def test_lat():
     assert w.lat == -1
 
 
-@raises(AttributeError)
 def test_lat_set():
     w = _wcs.Wcsprm()
-    w.lat = 0
+    with pytest.raises(AttributeError):
+        w.lat = 0
 
 
 def test_latpole():
@@ -537,14 +554,13 @@ def test_latpole():
 
 def test_lattyp():
     w = _wcs.Wcsprm()
-    print(repr(w.lattyp))
     assert w.lattyp == "    "
 
 
-@raises(AttributeError)
 def test_lattyp_set():
     w = _wcs.Wcsprm()
-    w.lattyp = 0
+    with pytest.raises(AttributeError):
+        w.lattyp = 0
 
 
 def test_lng():
@@ -552,10 +568,10 @@ def test_lng():
     assert w.lng == -1
 
 
-@raises(AttributeError)
 def test_lng_set():
     w = _wcs.Wcsprm()
-    w.lng = 0
+    with pytest.raises(AttributeError):
+        w.lng = 0
 
 
 def test_lngtyp():
@@ -563,10 +579,10 @@ def test_lngtyp():
     assert w.lngtyp == "    "
 
 
-@raises(AttributeError)
 def test_lngtyp_set():
     w = _wcs.Wcsprm()
-    w.lngtyp = 0
+    with pytest.raises(AttributeError):
+        w.lngtyp = 0
 
 
 def test_lonpole():
@@ -580,7 +596,7 @@ def test_lonpole():
 
 def test_mix():
     w = _wcs.Wcsprm()
-    w.ctype = [b'RA---TAN', 'DEC--TAN']
+    w.ctype = [b"RA---TAN", "DEC--TAN"]
     with pytest.raises(_wcs.InvalidCoordinateError):
         w.mix(1, 1, [240, 480], 1, 5, [0, 2], [54, 32], 1)
 
@@ -605,9 +621,9 @@ def test_mjdobs():
 
 def test_name():
     w = _wcs.Wcsprm()
-    assert w.name == ''
-    w.name = 'foo'
-    assert w.name == 'foo'
+    assert w.name == ""
+    w.name = "foo"
+    assert w.name == "foo"
 
 
 def test_naxis():
@@ -615,10 +631,10 @@ def test_naxis():
     assert w.naxis == 2
 
 
-@raises(AttributeError)
 def test_naxis_set():
     w = _wcs.Wcsprm()
-    w.naxis = 4
+    with pytest.raises(AttributeError):
+        w.naxis = 4
 
 
 def test_obsgeo():
@@ -642,12 +658,12 @@ def test_pc():
     w.pc = w.pc
 
 
-@raises(AttributeError)
 def test_pc_missing():
     w = _wcs.Wcsprm()
     w.cd = [[1, 0], [0, 1]]
     assert not w.has_pc()
-    w.pc
+    with pytest.raises(AttributeError):
+        w.pc
 
 
 def test_phi0():
@@ -659,16 +675,16 @@ def test_phi0():
     assert np.isnan(w.phi0)
 
 
-@raises(AssertionError)
 def test_piximg_matrix():
     w = _wcs.Wcsprm()
-    w.piximg_matrix
+    with pytest.raises(AssertionError):
+        w.piximg_matrix
 
 
-@raises(AttributeError)
 def test_piximg_matrix2():
     w = _wcs.Wcsprm()
-    w.piximg_matrix = None
+    with pytest.raises(AttributeError):
+        w.piximg_matrix = None
 
 
 def test_print_contents():
@@ -680,9 +696,9 @@ def test_print_contents():
 
 def test_radesys():
     w = _wcs.Wcsprm()
-    assert w.radesys == ''
-    w.radesys = 'foo'
-    assert w.radesys == 'foo'
+    assert w.radesys == ""
+    w.radesys = "foo"
+    assert w.radesys == "foo"
 
 
 def test_restfrq():
@@ -715,21 +731,20 @@ def test_set_ps_realloc():
 
 def test_set_pv():
     w = _wcs.Wcsprm()
-    data = [(0, 0, 42.), (1, 1, 54.)]
+    data = [(0, 0, 42.0), (1, 1, 54.0)]
     w.set_pv(data)
     assert w.get_pv() == data
 
 
 def test_set_pv_realloc():
     w = _wcs.Wcsprm()
-    w.set_pv([(0, 0, 42.)] * 16)
+    w.set_pv([(0, 0, 42.0)] * 16)
 
 
 def test_spcfix():
     # TODO: We need some data with broken spectral headers here to
     # really test
-    header = get_pkg_data_contents(
-        'data/spectra/orion-velo-1.hdr', encoding='binary')
+    header = get_pkg_data_contents("data/spectra/orion-velo-1.hdr", encoding="binary")
     w = _wcs.Wcsprm(header)
     assert w.spcfix() == -1
 
@@ -739,17 +754,17 @@ def test_spec():
     assert w.spec == -1
 
 
-@raises(AttributeError)
 def test_spec_set():
     w = _wcs.Wcsprm()
-    w.spec = 0
+    with pytest.raises(AttributeError):
+        w.spec = 0
 
 
 def test_specsys():
     w = _wcs.Wcsprm()
-    assert w.specsys == ''
-    w.specsys = 'foo'
-    assert w.specsys == 'foo'
+    assert w.specsys == ""
+    w.specsys = "foo"
+    assert w.specsys == "foo"
 
 
 def test_sptr():
@@ -759,16 +774,16 @@ def test_sptr():
 
 def test_ssysobs():
     w = _wcs.Wcsprm()
-    assert w.ssysobs == ''
-    w.ssysobs = 'foo'
-    assert w.ssysobs == 'foo'
+    assert w.ssysobs == ""
+    w.ssysobs = "foo"
+    assert w.ssysobs == "foo"
 
 
 def test_ssyssrc():
     w = _wcs.Wcsprm()
-    assert w.ssyssrc == ''
-    w.ssyssrc = 'foo'
-    assert w.ssyssrc == 'foo'
+    assert w.ssyssrc == ""
+    w.ssyssrc = "foo"
+    assert w.ssyssrc == "foo"
 
 
 def test_tab():
@@ -828,7 +843,7 @@ def test_zsource():
 
 
 def test_cd_3d():
-    header = get_pkg_data_contents('data/3d_cd.hdr', encoding='binary')
+    header = get_pkg_data_contents("data/3d_cd.hdr", encoding="binary")
     w = _wcs.Wcsprm(header)
     assert w.cd.shape == (3, 3)
     assert w.get_pc().shape == (3, 3)
@@ -836,7 +851,7 @@ def test_cd_3d():
 
 
 def test_get_pc():
-    header = get_pkg_data_contents('data/3d_cd.hdr', encoding='binary')
+    header = get_pkg_data_contents("data/3d_cd.hdr", encoding="binary")
     w = _wcs.Wcsprm(header)
     pc = w.get_pc()
     try:
@@ -847,47 +862,48 @@ def test_get_pc():
         raise AssertionError()
 
 
-@raises(_wcs.SingularMatrixError)
 def test_detailed_err():
     w = _wcs.Wcsprm()
     w.pc = [[0, 0], [0, 0]]
-    w.set()
+    with pytest.raises(_wcs.SingularMatrixError):
+        w.set()
 
 
 def test_header_parse():
     from astropy.io import fits
+
     with get_pkg_data_fileobj(
-            'data/header_newlines.fits', encoding='binary') as test_file:
+        "data/header_newlines.fits", encoding="binary"
+    ) as test_file:
         hdulist = fits.open(test_file)
         with pytest.warns(FITSFixedWarning):
             w = wcs.WCS(hdulist[0].header)
-    assert w.wcs.ctype[0] == 'RA---TAN-SIP'
+    assert w.wcs.ctype[0] == "RA---TAN-SIP"
 
 
 def test_locale():
     try:
-        with _set_locale('fr_FR'):
-            header = get_pkg_data_contents('data/locale.hdr',
-                                           encoding='binary')
+        with _set_locale("fr_FR"):
+            header = get_pkg_data_contents("data/locale.hdr", encoding="binary")
             with pytest.warns(FITSFixedWarning):
                 w = _wcs.Wcsprm(header)
                 assert re.search("[0-9]+,[0-9]*", w.to_header()) is None
     except locale.Error:
         pytest.xfail(
             "Can't set to 'fr_FR' locale, perhaps because it is not installed "
-            "on this system")
+            "on this system"
+        )
 
 
-@raises(UnicodeEncodeError)
 def test_unicode():
     w = _wcs.Wcsprm()
-    w.alt = "‰"
+    with pytest.raises(UnicodeEncodeError):
+        w.alt = "‰"
 
 
 def test_sub_segfault():
-    # Issue #1960
-    header = fits.Header.fromtextfile(
-        get_pkg_data_filename('data/sub-segfault.hdr'))
+    """Issue #1960"""
+    header = fits.Header.fromtextfile(get_pkg_data_filename("data/sub-segfault.hdr"))
     w = wcs.WCS(header)
     w.sub([wcs.WCSSUB_CELESTIAL])
     gc.collect()
@@ -899,24 +915,23 @@ def test_bounds_check():
 
 
 def test_wcs_sub_error_message():
-    # Issue #1587
+    """Issue #1587"""
     w = _wcs.Wcsprm()
-    with pytest.raises(TypeError) as e:
-        w.sub('latitude')
-    assert e.match("axes must None, a sequence or an integer$")
+    with pytest.raises(TypeError, match="axes must None, a sequence or an integer$"):
+        w.sub("latitude")
 
 
 def test_wcs_sub():
-    # Issue #3356
+    """Issue #3356"""
     w = _wcs.Wcsprm()
-    w.sub(['latitude'])
+    w.sub(["latitude"])
 
     w = _wcs.Wcsprm()
-    w.sub([b'latitude'])
+    w.sub([b"latitude"])
 
 
 def test_compare():
-    header = get_pkg_data_contents('data/3d_cd.hdr', encoding='binary')
+    header = get_pkg_data_contents("data/3d_cd.hdr", encoding="binary")
     w = _wcs.Wcsprm(header)
     w2 = _wcs.Wcsprm(header)
 
@@ -941,13 +956,12 @@ def test_compare():
 
 def test_radesys_defaults():
     w = _wcs.Wcsprm()
-    w.ctype = ['RA---TAN', 'DEC--TAN']
+    w.ctype = ["RA---TAN", "DEC--TAN"]
     w.set()
     assert w.radesys == "ICRS"
 
 
 def test_radesys_defaults_full():
-
     # As described in Section 3.1 of the FITS standard "Equatorial and ecliptic
     # coordinates", for those systems the RADESYS keyword can be used to
     # indicate the equatorial/ecliptic frame to use. From the standard:
@@ -965,46 +979,46 @@ def test_radesys_defaults_full():
 
     # By default RADESYS is empty
     w = _wcs.Wcsprm(naxis=2)
-    assert w.radesys == ''
+    assert w.radesys == ""
     assert np.isnan(w.equinox)
 
     # For non-ecliptic or equatorial systems it is still empty
     w = _wcs.Wcsprm(naxis=2)
-    for ctype in [('GLON-CAR', 'GLAT-CAR'),
-                  ('SLON-SIN', 'SLAT-SIN')]:
+    for ctype in [("GLON-CAR", "GLAT-CAR"), ("SLON-SIN", "SLAT-SIN")]:
         w.ctype = ctype
         w.set()
-        assert w.radesys == ''
+        assert w.radesys == ""
         assert np.isnan(w.equinox)
 
-    for ctype in [('RA---TAN', 'DEC--TAN'),
-                  ('ELON-TAN', 'ELAT-TAN'),
-                  ('DEC--TAN', 'RA---TAN'),
-                  ('ELAT-TAN', 'ELON-TAN')]:
-
+    for ctype in [
+        ("RA---TAN", "DEC--TAN"),
+        ("ELON-TAN", "ELAT-TAN"),
+        ("DEC--TAN", "RA---TAN"),
+        ("ELAT-TAN", "ELON-TAN"),
+    ]:
         # Check defaults for RADESYS
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
         w.set()
-        assert w.radesys == 'ICRS'
+        assert w.radesys == "ICRS"
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
         w.equinox = 1980
         w.set()
-        assert w.radesys == 'FK4'
+        assert w.radesys == "FK4"
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
         w.equinox = 1984
         w.set()
-        assert w.radesys == 'FK5'
+        assert w.radesys == "FK5"
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
-        w.radesys = 'foo'
+        w.radesys = "foo"
         w.set()
-        assert w.radesys == 'foo'
+        assert w.radesys == "foo"
 
         # Check defaults for EQUINOX
         w = _wcs.Wcsprm(naxis=2)
@@ -1014,75 +1028,80 @@ def test_radesys_defaults_full():
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
-        w.radesys = 'ICRS'
+        w.radesys = "ICRS"
         w.set()
         assert np.isnan(w.equinox)
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
-        w.radesys = 'FK5'
+        w.radesys = "FK5"
         w.set()
-        assert w.equinox == 2000.
+        assert w.equinox == 2000.0
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
-        w.radesys = 'FK4'
+        w.radesys = "FK4"
         w.set()
         assert w.equinox == 1950
 
         w = _wcs.Wcsprm(naxis=2)
         w.ctype = ctype
-        w.radesys = 'FK4-NO-E'
+        w.radesys = "FK4-NO-E"
         w.set()
         assert w.equinox == 1950
 
 
 def test_iteration():
     world = np.array(
-        [[-0.58995335, -0.5],
-         [0.00664326, -0.5],
-         [-0.58995335, -0.25],
-         [0.00664326, -0.25],
-         [-0.58995335, 0.],
-         [0.00664326, 0.],
-         [-0.58995335, 0.25],
-         [0.00664326, 0.25],
-         [-0.58995335, 0.5],
-         [0.00664326, 0.5]],
-        float
+        [
+            [-0.58995335, -0.5],
+            [0.00664326, -0.5],
+            [-0.58995335, -0.25],
+            [0.00664326, -0.25],
+            [-0.58995335, 0.0],
+            [0.00664326, 0.0],
+            [-0.58995335, 0.25],
+            [0.00664326, 0.25],
+            [-0.58995335, 0.5],
+            [0.00664326, 0.5],
+        ],
+        float,
     )
 
     w = wcs.WCS()
-    w.wcs.ctype = ['GLON-CAR', 'GLAT-CAR']
+    w.wcs.ctype = ["GLON-CAR", "GLAT-CAR"]
     w.wcs.cdelt = [-0.006666666828, 0.006666666828]
     w.wcs.crpix = [75.907, 74.8485]
     x = w.wcs_world2pix(world, 1)
 
     expected = np.array(
-        [[1.64400000e+02, -1.51498185e-01],
-         [7.49105110e+01, -1.51498185e-01],
-         [1.64400000e+02, 3.73485009e+01],
-         [7.49105110e+01, 3.73485009e+01],
-         [1.64400000e+02, 7.48485000e+01],
-         [7.49105110e+01, 7.48485000e+01],
-         [1.64400000e+02, 1.12348499e+02],
-         [7.49105110e+01, 1.12348499e+02],
-         [1.64400000e+02, 1.49848498e+02],
-         [7.49105110e+01, 1.49848498e+02]],
-        float)
+        [
+            [1.64400000e02, -1.51498185e-01],
+            [7.49105110e01, -1.51498185e-01],
+            [1.64400000e02, 3.73485009e01],
+            [7.49105110e01, 3.73485009e01],
+            [1.64400000e02, 7.48485000e01],
+            [7.49105110e01, 7.48485000e01],
+            [1.64400000e02, 1.12348499e02],
+            [7.49105110e01, 1.12348499e02],
+            [1.64400000e02, 1.49848498e02],
+            [7.49105110e01, 1.49848498e02],
+        ],
+        float,
+    )
 
     assert_array_almost_equal(x, expected)
 
     w2 = w.wcs_pix2world(x, 1)
 
-    world[:, 0] %= 360.
+    world[:, 0] %= 360.0
 
     assert_array_almost_equal(w2, world)
 
 
 def test_invalid_args():
     with pytest.raises(TypeError):
-        _wcs.Wcsprm(keysel='A')
+        _wcs.Wcsprm(keysel="A")
 
     with pytest.raises(ValueError):
         _wcs.Wcsprm(keysel=2)
@@ -1093,16 +1112,15 @@ def test_invalid_args():
     with pytest.raises(ValueError):
         _wcs.Wcsprm(naxis=64)
 
-    header = get_pkg_data_contents(
-        'data/spectra/orion-velo-1.hdr', encoding='binary')
+    header = get_pkg_data_contents("data/spectra/orion-velo-1.hdr", encoding="binary")
     with pytest.raises(ValueError):
-        _wcs.Wcsprm(header, relax='FOO')
+        _wcs.Wcsprm(header, relax="FOO")
 
     with pytest.raises(ValueError):
         _wcs.Wcsprm(header, naxis=3)
 
     with pytest.raises(KeyError):
-        _wcs.Wcsprm(header, key='A')
+        _wcs.Wcsprm(header, key="A")
 
 
 # Test keywords in the Time standard
@@ -1110,48 +1128,74 @@ def test_invalid_args():
 
 def test_datebeg():
     w = _wcs.Wcsprm()
-    assert w.datebeg == ''
-    w.datebeg = '2001-02-11'
-    assert w.datebeg == '2001-02-11'
-    w.datebeg = '31/12/99'
+    assert w.datebeg == ""
+    w.datebeg = "2001-02-11"
+    assert w.datebeg == "2001-02-11"
+    w.datebeg = "31/12/99"
     fix_ref = {
-        'cdfix': 'No change',
-        'cylfix': 'No change',
-        'obsfix': 'No change',
-        'datfix': "Invalid DATE-BEG format '31/12/99'",
-        'spcfix': 'No change',
-        'unitfix': 'No change',
-        'celfix': 'No change'}
+        "cdfix": "No change",
+        "cylfix": "No change",
+        "obsfix": "No change",
+        "datfix": "Invalid DATE-BEG format '31/12/99'",
+        "spcfix": "No change",
+        "unitfix": "No change",
+        "celfix": "No change",
+    }
 
-    if LooseVersion(wcs._wcs.__version__) >= '7.3':
-        fix_ref['datfix'] = "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref['datfix']
-    elif LooseVersion(wcs._wcs.__version__) >= '7.1':
-        fix_ref['datfix'] = "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref['datfix']
+    if Version(wcs._wcs.__version__) >= Version("7.3"):
+        fix_ref["datfix"] = (
+            "Set DATEREF to '1858-11-17' from MJDREF.\n" + fix_ref["datfix"]
+        )
+    elif Version(wcs._wcs.__version__) >= Version("7.1"):
+        fix_ref["datfix"] = (
+            "Set DATE-REF to '1858-11-17' from MJD-REF.\n" + fix_ref["datfix"]
+        )
 
     assert w.fix() == fix_ref
 
 
-char_keys = ['timesys', 'trefpos', 'trefdir', 'plephem', 'timeunit',
-             'dateref', 'dateavg', 'dateend']
+char_keys = [
+    "timesys",
+    "trefpos",
+    "trefdir",
+    "plephem",
+    "timeunit",
+    "dateref",
+    "dateavg",
+    "dateend",
+]
 
 
-@pytest.mark.parametrize('key', char_keys)
+@pytest.mark.parametrize("key", char_keys)
 def test_char_keys(key):
     w = _wcs.Wcsprm()
-    assert getattr(w, key) == ''
+    assert getattr(w, key) == ""
     setattr(w, key, "foo")
-    assert getattr(w, key) == 'foo'
+    assert getattr(w, key) == "foo"
     with pytest.raises(TypeError):
         setattr(w, key, 42)
 
 
-num_keys = ['mjdobs', 'mjdbeg', 'mjdend', 'jepoch',
-            'bepoch', 'tstart', 'tstop', 'xposure', 'timsyer',
-            'timrder', 'timedel', 'timepixr', 'timeoffs',
-            'telapse', 'xposure']
+num_keys = [
+    "mjdobs",
+    "mjdbeg",
+    "mjdend",
+    "jepoch",
+    "bepoch",
+    "tstart",
+    "tstop",
+    "xposure",
+    "timsyer",
+    "timrder",
+    "timedel",
+    "timepixr",
+    "timeoffs",
+    "telapse",
+    "xposure",
+]
 
 
-@pytest.mark.parametrize('key', num_keys)
+@pytest.mark.parametrize("key", num_keys)
 def test_num_keys(key):
     w = _wcs.Wcsprm()
     assert np.isnan(getattr(w, key))
@@ -1163,17 +1207,17 @@ def test_num_keys(key):
         setattr(w, key, "foo")
 
 
-@pytest.mark.parametrize('key', ['czphs', 'cperi', 'mjdref'])
+@pytest.mark.parametrize("key", ["czphs", "cperi", "mjdref"])
 def test_array_keys(key):
     w = _wcs.Wcsprm()
     attr = getattr(w, key)
-    if key == 'mjdref' and LooseVersion(_wcs.__version__) >= '7.1':
+    if key == "mjdref" and Version(_wcs.__version__) >= Version("7.1"):
         assert np.allclose(attr, [0, 0])
     else:
         assert np.all(np.isnan(attr))
     assert attr.dtype == float
-    setattr(w, key, [1., 2.])
-    assert_array_equal(getattr(w, key), [1., 2.])
+    setattr(w, key, [1.0, 2.0])
+    assert_array_equal(getattr(w, key), [1.0, 2.0])
     with pytest.raises(ValueError):
         setattr(w, key, ["foo", "bar"])
     with pytest.raises(ValueError):
